#
# spec file
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor strict%{nil}
%if "%{flavor}" == ""
%define name_suffix %{nil}
%else
%define name_suffix -%{flavor}
%endif
Name:           rpmlint%{name_suffix}
Version:        2.6.1+git20250204.53a229c0
Release:        1.1
Summary:        RPM file correctness checker
License:        GPL-2.0-or-later
URL:            https://github.com/rpm-software-management/rpmlint
Source0:        rpmlint-%{version}.tar.xz
Patch0:         disable-flake-and-cov.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildArch:      noarch
%if "%{flavor}" == "test"
BuildRequires:  appstream-glib
BuildRequires:  binutils
BuildRequires:  checkbashisms
BuildRequires:  dash
BuildRequires:  desktop-file-utils
BuildRequires:  myspell-cs_CZ
BuildRequires:  myspell-en_US
BuildRequires:  python3-pybeam
BuildRequires:  python3-pyenchant
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-xdist
BuildRequires:  python3-python-magic
BuildRequires:  python3-pyxdg
BuildRequires:  python3-rpm
BuildRequires:  python3-tomli-w
BuildRequires:  python3-zstandard
BuildRequires:  xz
BuildRequires:  (python3-tomli if python3-base < 3.11)
%ifarch x86_64
BuildRequires:  glibc-32bit
%endif
%endif
%if "%{flavor}" == ""
Requires:       appstream-glib
Requires:       bash
Requires:       binutils
Requires:       checkbashisms
Requires:       cpio
Requires:       dash
Requires:       desktop-file-utils
Requires:       file
Requires:       findutils
Requires:       myspell-en_US
Requires:       python3-pybeam
Requires:       python3-pyenchant
Requires:       python3-python-magic
Requires:       python3-pyxdg
Requires:       python3-rpm
%if 0%{?python3_version_nodots} < 311
Requires:       python3-tomli
%endif
Requires:       python3-tomli-w
Requires:       python3-zstandard
Requires:       rpm-build
%endif

%description
rpmlint is a tool to check common errors on RPM packages. Binary and
source packages can be checked.

%prep
%autosetup -p1 -n rpmlint-%{version}

%build
%if "%{flavor}" != "strict"
%python3_pyproject_wheel
%endif

%install
%if "%{flavor}" != "test"
mkdir -p %{buildroot}%{_sysconfdir}/xdg/rpmlint
install -m644 configs/openSUSE/scoring-strict.override.toml %{buildroot}%{_sysconfdir}/xdg/rpmlint
%endif

%if "%{flavor}" == ""
%python3_pyproject_install
fdupes %{buildroot}%{python3_sitelib}
install -m644 configs/openSUSE/* %{buildroot}%{_sysconfdir}/xdg/rpmlint
rm %{buildroot}%{_sysconfdir}/xdg/rpmlint/scoring-strict.override.toml
%endif

%if "%{flavor}" == "test"
%check
python3 -m pytest
%endif

%files
%if "%{flavor}" == ""
%license COPYING
%doc README*
%{_bindir}/rpmlint
%{_bindir}/rpmdiff
%{python3_sitelib}/rpmlint*
%dir %{_sysconfdir}/xdg/rpmlint
%config %{_sysconfdir}/xdg/rpmlint/*

%else
%if "%{flavor}" == "strict"
%dir %{_sysconfdir}/xdg/rpmlint
%config %{_sysconfdir}/xdg/rpmlint/scoring-strict.override.toml
%endif
%endif

%changelog
* Tue Feb  4 2025 matthias.gerstner@suse.com
- Update to version 2.6.1+git20250204.53a229c0:
  * dbus-services: drop no longer needed temporary sssd-dbus entry
  * dbus-services: adjust sssd-dbus hash (bsc#1235724)
* Fri Jan 31 2025 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20250131.362f064:
  * dbus-services: drop RemoteDesktop.service which is no longer packages.
  * dbus-services: drop no longer packaged kcm_sddm service
  * dbus-services: drop no longer packages scmon Pkcs11Monitor.conf
* Tue Jan 28 2025 matthias.gerstner@suse.com
- Update to version 2.6.1+git20250128.c5fd1e77:
  * dbus-services: tuned-ppd: add new org.freedesktop.UPower names
* Thu Jan  9 2025 matthias.gerstner@suse.com
- Update to version 2.6.1+git20250109.dfc27180:
  * whitelistings: add sssd permissions drop-in file for helper caps (bsc#1233131)
* Fri Dec  6 2024 matthias.gerstner@suse.com
- Update to version 2.6.1+git20241206.0bc429f2:
  * dbus-services: fix mistake in sddm-kalpa whitelisting (bsc#1232647)
* Fri Nov 29 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20241129.0f107c1:
  * dbus-services: whitelist tuned-ppd (bsc#1232412)
- Add format_spec_file service in manual mode
- Convert existing services from disabled to manual mode
* Tue Nov 19 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20241119.2e09c30:
  * dbus-services: whitelist supergfxctl (bsc#1232776)
* Fri Nov 15 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20241115.da2ed92:
  * polkit-rules-whitelist: adjust package name for sssd (bsc#1230051)
  * SpecCheck: Update suse-update-desktop-file-deprecated message
  * FilesCheck: Do not error about non-readable %%ghost
  * test: Mocking TagsCheck binaries
  * CI: exclude test/files from pyupgrade
  * test: exclude test files from ruff check
  * test: Fix flake8 issues
  * flake8: Skip test files from flake8
  * test: Move doc pacakges to mock
  * test: Normalize mock_zypp_syntax
  * test: Normalize mock_xinetd
  * test: Normalize mock_tmp_files
  * test: Normalize mock_sysvinitonsystemd
  * test: Normalize mock_shlib_policy
  * test: Normalize mock_pkgconfig
  * test: Normalize mock_pam_modules
  * test: Normalize mock_mixed_ownership
  * test: Normalize mock_menuxdg
  * test: Normalize mock_LSB
  * test: Remove not needed mock_lib_dependency.py
  * test: Normalize mock_icon_sizes
  * test: Normalize mock_i18n
  * test: Normalize mock_files
  * test: Normalize mock_FHS
  * test: Normalize mock_erlang.py
  * test: Normalize mock_dbus_policy.py
  * test: Replace logrotate rpm with mock
  * test: Normalize mock_config_files
  * test: Normalize mock_build_root
  * test: Normalize mock_build_date
  * test: Normalize mock_bashisms
  * test: Normalize mock_appdata
  * test: Use skipif instead of early return in test_extract_fail
  * Remove fPing binary not needed anymore
* Mon Nov 11 2024 dimstar@opensuse.org
- Update to version 2.6.1+git20241111.4884f6a:
  * SUIDPermissionsCheck: Escape path for regular expression
  * false positive: systemd-service-without-service_del_postun
* Thu Nov  7 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20241107.1b69a23:
  * dbus-services: whitelist sddm-kalpa (bsc#1232647)
  * dbus-services: replace generic comment for sddm
  * SUIDPermissionsCheck: chkstat to permctl rename
* Thu Oct 24 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20241024.1f09e50:
  * whitelistings: add libcgroup PAM module and setgid binary (bsc#1231381)
* Mon Oct 21 2024 wolfgang.frisch@suse.com
- Update to version 2.6.1+git20241017.b725184:
  * dbus-services: deepin-system-monitor (bsc#1230018)
* Wed Oct 16 2024 matthias.gerstner@suse.com
- Update to version 2.6.1+git20241016.ae941eb7:
  * dbus-services: adjust gnome-remote-desktop to version 47 (bsc#1230406)
  * Add new warning about the usage of %%suse_update_desktop_file
* Fri Sep 20 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20240918.5cb5647:
  * opensuse: explain pull requests more precisely
  * Fix pam-module test binary package
  * Fix tests with new rpm2cpio command
  * openSUSE: strict policy to ERR on patch-macro-old-format
  * Add traefik user and group
  * test: Fix test_extract_fail when running as root
  * Update users-groups.toml 3proxy (#1267)
  * Add user and group sssd
  * Test: Add missing test file for test_files.py
  * Remove not needed binary rpm
  * Replace bin in test_files.py
  * Replace bin in test_shlib_policy.py
  * Rewrite test_extract to *_fail variant that tests an expected failure in rpm2cpio
  * Exclude python311-pytest-xprocess from test_lint because rpm2cpio fails on it
  * Remove test_directory_without_x_permission2 test
  * Don't mask rpm2cpio failure in Pkg._extract_rpm()
  * Replace bin in test_icon_sizes.py
  * Replace bin in test_build_date.py
  * Replace bin in test_bashisms.py
  * test: Add bad unicode desktop file
  * Delete not needed test files
  * Replace bin in test_LSB.py
  * Replace bin in test_pam_modules.py
  * Replace bin in test_sysvinitonsystemd.py
  * Delete not needed test files
  * Replace bin in test_menuxdg.py in the absence of the penultimate test that must be corrected
  * Replace bin in test_menuxdg.py
  * Replace bin in test_pkgconfig.py
  * Replace bin in test_FHS.py
  * Remove not needed test files
  * Replace bin in test_mixed_ownership.py
  * Replace bin in test_build_root.py
  * Replace bin in test_dbus_policy.py
  * Fix for bug detected in test_appdata.py
  * Replace bin in test_appdata.py
  * Remove not needed binary files.
  * Replace bin in test_lib_dependency.py
  * Replace bin in test_erlang.py
  * Delete not needed files
  * Update users-groups.toml
  * Replace bin in test_mixed_ownership.py
* Wed Sep 18 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20240918.9e0efea:
  * dbus-services: gdm: temporarily whitelist old version (bsc#1230466)
  * dbus-services: sssd: temporarily whitelist old version (bsc#1230051)
  * sysctl-whitelist: traefik: increase socket buffers (bsc#1230555)
* Thu Sep 12 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20240912.cce07f4:
  * dbus-services: gdm update (bsc#1230466)
  * pam-modules: pam_limits.so moved from `pam` to `pam-extra` (bsc#1230447)
  * polkit-rules: add whitelisting for sssd smartcard access (bsc#1230051)
  * dbus-services: adjust digests for sssd (bsc#1230051)
* Tue Sep  3 2024 wolfgang.frisch@suse.com
- Update to version 2.6.1+git20240903.3c1fddf:
  * configs/openSUSE/users-groups.toml: add nqptp (boo#1213060)
* Fri Aug  9 2024 filippo.bonazzi@suse.com
- Update to version 2.6.1+git20240807.9387990:
  * dbus-services: systemd: remove outdated hashes (bsc#1225317)
* Fri Aug  2 2024 daniel.garcia@suse.com
- Update to version 2.6.1+git20240802.da40b67:
  * Release 2.6.1
  * FilesCheck: Fix zero perm check with binaries
  * FilesCheck: Fix zero permission check with folder
  * Update openSUSE's licenses.toml
* Thu Aug  1 2024 filippo.bonazzi@suse.com
- Update to version 2.6.0+git20240801.f3e815d:
  * sysctl-whitelist: kernel.pid_max entry moved (bsc#1228731)
  * Update openSUSE's licenses.toml
  * configs/openSUSE/users-groups.toml: add user and group woodpecker
  * configs/openSUSE/users-groups.toml: add user and group vault-sync
  * configs/openSUSE/users-groups.toml: add user and group openbao
  * configs/openSUSE/users-groups.toml: add user and group alloy
  * Release 2.6.0
  * Test: Fix test_config error raised by new ruff
  * CI: Fix ruff call with modern syntax
  * Update main.yml
  * FilesCheck: Remove trailing slashes
  * FilesCheck: zero-perms differentiate between ghost and normal files
  * FilesCheck: warn about files with zero perms
  * Create Mock packages for tests in config_files, i18n, tmp_file and zypp_syntax (#1235)
  * users-groups.toml: add caddy
  * PythonCheck: simplify requirement check using metadata
* Mon Jun 24 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240624.609e1aa:
  * sysctl-whitelist: move 50-coredump.conf to systemd main package (bsc#1226865)
  * sysctl-whitelist: aaa_base: new sub-package to disable YAMA (bsc#1226460)
  * sysctl-whitelist: aaa_base: adjust 50-default.conf digest (bsc#1226464)
* Wed Jun 19 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240619.f4bc3a6:
  * dbus-services: systemd: keep the old whitelisting temporarily (bsc#1225317)
  * dbus-services: whitelist kdeplasma6-addons kameleonhelper (bsc#1226306)
  * dbus-services: adjust backintime whitelisting to etc->usr move (bsc#1226446)
* Thu Jun 13 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240613.c7bc651:
  * whitelistings: systemd v256 (bsc#1225317)
* Tue Jun 11 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240611.11134e8:
  * whitelist valkey (bsc#1226083)
* Wed May 22 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240522.59c66e6:
  * whitelistings: add gnome-remote-desktop Polkit and D-Bus components (bsc#1222159)
* Tue May 14 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240514.fd06b07:
  * zypper-plugins: adjust permissions-zypp-plugin to new permctl name
  * dbus-services: remove deepin-api entry until packaging issues are resolved
  * whitelistings: drop no longer needed KDE5 whitelistings
  * dbus-services: drop no longer present nfs-ganesha entry
  * whitelistings: drop no longer needed pam_dbus entries
* Tue Apr 16 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240416.97c8fad:
  * pam-modules: whitelist pam_oslogin_admin.so (bsc#1222457)
  * Revert "pam-modules: whitelist pam_lastlog2 now moved to util-linux (bsc#1222329)"
  * Clarify what the real intent is of this check
  * openSUSE: Add netdata user/group
  * Add forgejo group and user
  * remove comment in setup.cfg
  * test: mocked package in test_xinetd.py
* Mon Apr  8 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240408.62c3097:
  * dbus-services: whitelist dnf5daemon-server (bsc#1218327)
* Fri Apr  5 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240405.5171234:
  * pam-modules: whitelist pam_lastlog2 now moved to util-linux (bsc#1222329)
* Wed Apr  3 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240403.33599c3:
  * dbus-services: power-profiles-daemon: reinstate legacy D-Bus whitelisting (bsc#1219957)
  * Revert "dbus-services: Still provide old GDM whitelisting (bsc#1218922)"
* Mon Mar 25 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240325.982d664:
  * dbus-services: power-profiles-daemon (bsc#1219956) (#1197)
  * SpecCheck: Add no-%%check-section warning
  * Bump upper bound of suse_version to include ALP & current Factory
  * test: add mocks folder and mocks for duplicates check
  * pkg: remove unicode type reference in is_utf8_bytestr exception
  * Refactored the is_utf8_bytestr function
  * readme: More specific title for building section
  * test: imporve fixtures in test_duplicates.py
  * Add building documentation
  * Update README.md
* Mon Mar 11 2024 Ben Greiner <code@bnavigator.de>
- Also fix the runtime requirement syntax
* Sun Mar 10 2024 Ben Greiner <code@bnavigator.de>
- Fix tomli requirement: It was never pulled in by obs explicitly
  but declared required in rpmbuild. Pytest removed the requirement
  that masked this issue.We actually don't need it with
  python >= 3.11
* Fri Mar  8 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240308.ec22ec6:
  * dbus-services: Still provide old GDM whitelisting (bsc#1218922)
* Wed Mar  6 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240306.d765521:
  * dbus-services: whitelist sddm-kcm6 (bsc#1217188)
* Tue Mar  5 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240305.3e99616:
  * whitelistings: merge redundant systemd vs. systemd-mini entries
  * pam-modules: also whitelisted pam_system_loadkey for systemd-mini (bsc#1220249)
  * dbus-services: adjust gdm whitelisting (bsc#1218922)
* Fri Mar  1 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240229.92123b5:
  * dbus-services: whitelist drkonqi KDE6 update (bsc#1220190)
  * pam-modules: whitelist pam_systemd_loadkey.so (bsc#1220249)
* Mon Feb 26 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240226.8b18627:
  * dbus-services: whitelist kde-inotify-survey with KDE6 changes (bsc#1217191)
  * dbus-services whitelist: adjust kde6 digests after fix in kauth6 (bsc#1220215)
  * CI: Reenable mageia-cauldron in packit
  * test: Add tests to check non-standard-dir-perm
  * SpecCheck: Add patch-macro-old-format check
  * BinariesCheck: do not mark as binary eBPF ELF files
  * change pyproject ruff config to toplevel
  * SystemIstallCheck: Allow %%service_del_postun_without_restart macro usage
  * test: Lazy load mock packages
  * test: Improve name of mock packages
  * Fix the errors and suggestions to the flake8 command
  * Clean all tests file
  * config: Do not filter python-leftover-require for fedora
  * Fix misspelled variable: ENGLISH_ENVIROMENT to ENGLISH_ENVIRONMENT
  * Clean tests file
* Fri Feb 16 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240215.29f50e5:
  * dbus-services: update systemd-homed (DeactivateAllHomes method, bsc#1219916)
  * dbus-services: whitelist plasma6-workspace fontinst service (bsc#1217186)
  * dbus-services: whitelist powerdevil6 (bsc#1217187)
  * dbus-services: whitelist plasma6-disks (bsc#1217185)
  * dbus-services: whitelist plasma6-desktop kcmclock (bsc#1217184)
  * pam-modules: whitelist pam_kwallet6 (bsc#1217183)
  * dbus-services: whitelist libksysguard6-plugins (bsc#1217182)
  * zypper-plugins: adjust libzypp-plugin-appdata to new content (bsc#1219873)
  * dbus-services: whitelist kinfocenter6 (bsc#1217179)
  * dbus-services: whitelist kf6-kauth (bsc#1217178)
  * SUIDPermissionsCheck: support new /usr/share/permissions/packages.d dir
* Thu Feb  8 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240207.4a699fe:
  * sysctl-whitelist: update YAMA config (bsc#1219656)
* Tue Feb  6 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240206.b0eda3c:
  * users-groups: add groups for usbauth-notifier
  * cron-whitelist: patch2mail now uses systemd-timers
  * Register greeter user and group
* Thu Feb  1 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240201.be433b6:
  * pam-modules: whitelist pam_canonicalize_user (bsc#1219358)
* Wed Jan 31 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240131.374af17:
  * sendmail: permissions moved from /etc to /usr/share/permissions (bsc#1219339)
* Tue Jan 30 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240130.b66a310:
  * sendmail: permissions moved from /etc to /usr/share/permissions (bsc#1219339)
* Tue Jan 30 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240130.4cdb3e1:
  * Move rpm2cpio to one line
  * PythonCheck: Check for python deps like python3.12dist(foo)
  * config: Filter python require checks for Fedora
* Mon Jan 29 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240129.d2cbb70:
  * test_file_digest: cover new glob features in package and path names
  * sysctl-whitelist: use new package glob pattern
  * FileDigestCheck: support glob patterns in package names
  * FileDigestCheck: make glob patterns in filenames explicit
* Thu Jan 25 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240125.d0146be:
  * sysctl-whitelist: add another package name for kubernetes1.29 (bsc#1219168)
  * check: Implement reset method in checks
  * Disable Mageia CI builds due to system problem
  * check: Implement reset method in checks
  * test: Add another test for patch-not-applied
  * read rpm package directly with open() while extracting
  * remove redundant TODO comments; checking is handled with check_output() pretty well now
  * leave rpm2cpio as fallback for distros which do not have rpm2archive available yet
  * fix warnings about import order, attempt 2
  * fix warnings about import order
  * Fixes for nsafe shell command
  * Drop rpm2cpio usage entirely
  * Adding support for RPM packages containing files greater than 4GB
  * lint: Reset all checks for each package
  * test: Extend tag tests to check 'W: missing-dependency-on'
* Mon Jan 15 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240115.66db794:
  * Fix digester for cronie whitelisting (bsc#1218756)
* Mon Jan 15 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240115.e28fef0:
  * cron-whitelist: adjust cronie-anacron again (bsc#1218756)
* Fri Jan 12 2024 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20240112.c87408b:
  * systemd-tmpfiles whitelist: adjust package name for libtss-fapi
  * pam-modules: separate standard PAM module that have been already reviewed
* Tue Jan  9 2024 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20240109.b4e5f72:
  * dbus-services: certmonger: .conf renamed (bsc#1218616)
* Wed Dec 20 2023 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20231220.9e24b84:
  * cron-whitelist: update cronie-anacron digest (bsc#1218107)
  * SUIDPermissionsCheck: fix broken warnings and harmonize code
* Thu Dec 14 2023 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20231214.5f62def:
  * Fix Aeon/Kalpa whitelisting distinct filenames (bsc#1217706, bsc#1217707)
* Thu Dec 14 2023 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20231214.ab9d731:
  * polkit rules whitelisting: add gamemode rules (bsc#1217915)
* Mon Dec 11 2023 matthias.gerstner@suse.com
- Update to version 2.5.0+git20231211.15d0caff:
  * polkit-rules, sudoers: add plasma-branding-Kalpa for special wheel group handling (bsc#1217707, bsc#1217706)
  * cron-whitelist: remove obsolete opa-ff entries
  * cron-whitelist: remove obsolete logdigest entries
  * fix readelf output encoding handling of errors
  * Ignore (and escape) symbols that are not valid utf8
  * Revert "Disable Mageia CI builds due to system problem"
* Tue Dec  5 2023 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20231205.c211cee:
  * FileDigestCheck: Filter minor versions in shebangs.
  * Disable Mageia CI builds due to system problem
* Wed Nov 15 2023 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20231115.969a58b:
  * polkit-rules-whitelist: self auth as admin (bsc#1215652)
* Fri Nov  3 2023 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20231103.c416f34:
  * pam-modules: remove no longer packaged pam_oslogin_admin.so
  * cron-whitelist: remove tmpwatch which migrated to systemd timers (bsc#1115458)
  * cron-whitelist: drop sarg which as been replaced by systemd timers
  * pam-modules: whitelist pam-himmelblau (bsc#1215355)
* Thu Nov  2 2023 wolfgang.frisch@suse.com
- Update to version 2.5.0+git20231102.2aee727:
  * dbus-services: whitelist passim service (bsc#1216434)
  * CI: Add systemd-rpm-macros package
  * Add pgadmin user/group
  * Add missing dependency to rpmlint spec
  * Update search regexes for %%service_* macros
  * Don't skip systemd scriptlet test on Fedora
  * Improve systemd scriptlet test name
* Wed Oct 25 2023 filippo.bonazzi@suse.com
- Update to version 2.5.0+git20231025.2713543:
  * zypper-plugins: whitelist zypp-boot-plugin (bsc#1215988)
  * Release 2.5.0
  * Add new check to detect links to scripts
  * SpecCheck: Support "%%patch n" to detect applied patches
  * lint: Show dynamic description for WarnOnFunction config
  * description: Add files-duplicate description
  * descriptions: Add invalid-lc-messages-dir
  * test: Add some tests for I18NCheck
  * Add iso_15924 to LANGUAGES
  * pkg: Set default user/group as root for FakePkg files
  * pkg: Add linkto parameter to FakePkg files
  * pkg: Add filenames to FakePkg headers
  * pkg: Move scriptprog to AbstractPkg
* Wed Oct 11 2023 Daniel Garcia <daniel.garcia@suse.com>
- Use %%pyproject_wheel to build the package
* Tue Oct 10 2023 wolfgang.frisch@suse.com
- Update to version 2.4.0+git20231010.276506d:
  * dbus-services: adjust to etc -> usr move in thermald (bsc#1215873)
  * dbus-services: remove obsolete entry for sysprof
  * Use "int" as defaultdict factory instead of lambda
  * test: Replace bin in test_zypp_syntax
* Fri Oct  6 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20231006.4b34bab:
  * Whitelist dbus service and configuration for policycoreutils-dbus (bsc#1213435)
  * polkit-rules-whitelist: add fudo rules (bsc#1215948)
* Wed Sep 27 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230927.bf3988d:
  * Add whitelisting for 90-kubeadm.conf (bsc#1215542)
  * sysctl-whitelist: remove old microos-tools entry
* Mon Sep 18 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230918.4498739:
  * dbus-services: sddm-qt6 whitelisting (bsc#1215441)
* Mon Sep 18 2023 daniel.garcia@suse.com
- Update to version 2.4.0+git20230918.02ed553:
  * Fix time report function output string creation
* Fri Sep 15 2023 matthias.gerstner@suse.com
- Update to version 2.4.0+git20230915.acb9f8b2:
  * polkit, sudoers whitelist: add gnome-branding-Aeon (bsc#1215276)
* Fri Sep 15 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230915.ac23757:
  * dbus-services: update tukitd (bsc#1215216)
  * FileDigestCheck: do not use hash as variable name
  * FileDigestCheck: Adapt fstrings to python3.12 check
  * test: Remove real_files opotional parameter
  * Add 'nats' user for NATS Server
  * Add 'signaling' user for Nextcloud Talk Signaling Server
  * Add 'otobo' user and group, successor app for OTRS
  * PythonCheck: Add python-sphinx-doctrees-leftover
  * test: Allow external file content definition
  * test: Allow list of files in get_tested_mock_package
  * test: add test documentation
  * test: each file now default to empty content
  * test: mocked test_config_files
  * test: mocked newly added multiple-pyc-version tests
  * test: mocked test_duplicates tests
  * Refactored FakePkg with a new helper method for cleaner code in get_tested_mock_package
  * moved _gather_dep_info and _gather_aux to AbstractPkg
  * CI: removed GSoC23 branch for CI workflow
  * test: mocked python dependencies leftovers; and removed 2 binaries
  * copied _gather_deps_info and _gather_aux functions to FakePkg class
  * test: mocked test_python_dependencies_missing; also removed its two rpm binaries
  * test: removed binaries used for testing python package dependencies from metadata and requires.txt
  * test: mocked another metadata test that supports complex dependency statements
  * test: mocked test for metadata check in python package
  * test: mocked complex dependencies from metadata
  * test: mocked test for python dependencies from requires.txt
  * test: mocked test for python dependencies from metadata
  * modified if condition in add_file_with_content function
  * test: distutil test for python packages is mocked
  * tests: Refactored Python package tests using mocking for docs, src, and tests
  * test: Remove binary RPM packages with Python docs and docs modules
  * test: modified test_python_doc_module_in_package with mocking
  * test: mocked test_python_doc_in_package
  * flake8: fixed flake8 warnings
  * Flake8 suggestion
  * Update main.yml for GitHub Actions on branch GSoC23
  * No need to import FakePkg
  * changes as suggested
  * As suggested, I have made changes to to get_tested_mock_package to use API, instead of just kwargs
  * Tried to mock a test: test_binary.py
  * CI: Use pipx to install external dependencies
  * flake8: ignored double quotes with a comment
  * flake8: remove double quotes
  * add flake8 extra plugins
  * Use python-magic API when available
  * test: Skip test_executable_stack when ldd-failed
  * PythonCheck: Add check for *.pyc different version
* Fri Aug 18 2023 matthias.gerstner@suse.com
- Update to version 2.4.0+git20230818.5cdd21d0:
  * dbus-services: keep old deepin names around until rename is complete (bsc#1214101)
  * BinariesCheck: Allow ELF prefix in magic string
  * README: added test coverage badge
  * pkg_resource is deprecated, importlib and packaging are standard now
  * Change setuptools dependency version and license
  * Add 'rpmlint.descriptions' to packages on pyproject.toml
  * Move metadata from setup.py to pyproject.toml
* Thu Jul 27 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230727.0fd5122:
  * whitelists: adjust package for systemd-homed components (bsc#1213692)
* Thu Jul 13 2023 wolfgang.frisch@suse.com
- Update to version 2.4.0+git20230713.dfa31c7:
  * bsc#1213292: adjust timesync1 dbus whitelisting
  * spellcheck: Set lang to en_US when it's C
  * SpecCheck: Allow macros for special comments
  * rpmdiff: handle script argument with argparse
  * PythonCheck: Handle extras in req check
  * PythonCheck: Use packaging to parse deps strings
  * PythonCheck: Ignore python_version in requirements
  * PythonCheck: Support complex python requirements
  * SpecCheck: Check for NULL char in all lines
  * rpmdiff: adjust for rpm-4.19.0 API changes
  * DocCheck: adjust for rpm-4.19.0 API changes
  * dbus-services: drop whitelisting that was never put into production
  * openSUSE/users-groups: transmission
  * Releasing rpmlint as pre-commit hook
* Fri Jun  2 2023 matthias.gerstner@suse.com
- Update to version 2.4.0+git20230602.89901a92:
  * cron-whitelist: drop dead suse-texlive entry
  * pam-modules: drop dead pam_opie entry (sr#1065964)
  * dbus-services: drop no longer needed dinstaller services (bsc#1208394)
  * dbus-services: remove no longer packaged mumble-server (bsc#1209338)
* Wed May 17 2023 matthias.gerstner@suse.com
- Update to version 2.4.0+git20230517.2e069e5c:
  * dbus-services: rename com.deepin.api to org.deepin.dde (bsc#1211376)
* Tue May  9 2023 matthias.gerstner@suse.com
- Update to version 2.4.0+git20230509.6f11a918:
  * sudoers-whitelist: adjust monitoring-plugins-smart (bsc#1211003)
* Tue May  2 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230502.1ab1dde:
  * sysctl-whitelist: add kubernetes1.27 (bsc#1210951)
  * Add logo to README.md.
* Mon Apr 24 2023 mliska@suse.cz
- Update to version 2.4.0+git20230424.e2a5b62:
  * port to get_tested_path instead of testpath
  * Allow *args for get_tested_path.
  * tests: use get_tested_path rather than testpath
* Mon Apr 24 2023 mliska@suse.cz
- Update to version 2.4.0+git20230424.b8b7e4e:
  * Remove trailing whitespace.
  * pytest: fix one warning
  * Introducing new file 'pytest.ini' a conf file for pytest (#1047)
  * Add rpmlint.svg with the new rpmlint logo
-Rebase disable-flake-and-cov.patch.
* Fri Apr 21 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230421.f2ea8ab:
  * pam-modules: whitelist pam_wtmpdb (bsc#1209963)
  * Drop dependency on pytest-flake8 as it's unmaintained.
* Wed Apr 19 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230419.2b26601:
  * pam-modules: Move pam_timestamp, pam_issue and pam-userdb (bsc#1210371)
  * flake8: fix C419 Unnecessary list comprehension passed to any() prevents short-circuiting
* Tue Apr 11 2023 mliska@suse.cz
- Update to version 2.4.0+git20230411.8f9c3d4:
  * PythonCheck: Improve dependencies check
* Tue Apr 11 2023 mliska@suse.cz
- Update to version 2.4.0+git20230411.f83b036:
  * SpecCheck: Improve patch applied regex
* Mon Apr  3 2023 mliska@suse.cz
- Update to version 2.4.0+git20230403.7ce263c:
  * tests: make a local copy of configuration in test_binaries.py
* Mon Apr  3 2023 mliska@suse.cz
- Update to version 2.4.0+git20230403.cf6f584:
  * Add test for #1040.
  * Exclude systemd directory in UsrLibBinaryException
* Fri Mar 31 2023 mliska@suse.cz
- Update to version 2.4.0+git20230331.bc7b966:
  * dbus-services: add libproxy whitelisting (bsc#1209376)
* Fri Mar 31 2023 mliska@suse.cz
- Update to version 2.4.0+git20230331.8f6e31e:
  * PythonCheck: Handle complex dependency declaration gracefully
* Wed Mar 29 2023 mliska@suse.cz
- Update to version 2.4.0+git20230329.3cd1bcf:
  * packit: use python-magic python pages for openSUSE CI
  * openSUSE: Start using python-magic package in CI.
* Wed Mar 29 2023 Martin Liška <mliska@suse.cz>
- Depend on python-magic Python package.
* Mon Mar 27 2023 mliska@suse.cz
- Update to version 2.4.0+git20230327.f239521:
  * stringToVersion: make epoch always an integer
  * pytest: use tmp_path mock instead of tmpdir
  * pytest: disable legacypath
  * Replace one more usage of tmpdir in a test.
  * Pytest documentation recommends refactoring "tmpdir" to "tmp_path"
* Fri Mar 24 2023 mliska@suse.cz
- Update to version 2.4.0+git20230324.96c1ac0:
  * PythonCheck: Ignore python-devel in req check
  * PythonCheck: ignore python-base package in requirements check
  * PythonCheck: Remove spaces from requirements before compare
  * Add new check: patchable-function-entry-in-archive.
* Fri Mar 24 2023 mliska@suse.cz
- Update to version 2.4.0+git20230322.717aa4d:
  * pam-module whitelist: add lastlog2 (bsc#1209238)
* Tue Mar 21 2023 mliska@suse.cz
- Update to version 2.4.0+git20230321.8da9c94:
  * PythonCheck: Add python requirements verification
  * TagsCheck: handle license exception in first item of a grouping
  * TagsCheck: restore space exclusion to license_exception_regex
  * Fix TW CI due to the new flake8 release.
  * Remove unnnecesary lambda and map in favor generator expressions
  * Include -prof in devel packages regex
* Thu Mar 16 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230316.e10f602:
  * python3-pytest-flake8 is not anymore in Tumbleweed
  * sysctl-whitelist: add further kubernetes versions (bsc#1209363)
  * test_files : Add test for unexpanded macros in files. (#1023)
  * SpecCheck: allow more %%suse_version value comparisons
  * No need of using wheel: PEP 517
  * setup.cfg: rename license_file to license_files
  * setup.py: include rpmlint.descriptions in packages
* Tue Mar  7 2023 wolfgang.frisch@suse.com
- Update to version 2.4.0+git20230307.1e9f1e0:
  * d-bus services: add kde-inotify-survey (bsc#1208689)
  * Add missing newline at the end of TOML files.
  * Add missing newline at the end of file.
  * TagsCheck: handle license exception in grouping
* Fri Mar  3 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230303.8af2aa4:
  * polkit-rules-whitelist: adjust libvirt-daemon rule to new sub-package (bsc#1208876)
* Mon Feb 27 2023 mliska@suse.cz
- Update to version 2.4.0+git20230227.db0110c:
  * DbusPolicyCheck: use existing dbus-policy-missing-allow
  * DbusPolicyCheck: use existing dbus-policy-missing-allow
* Mon Feb 27 2023 mliska@suse.cz
- Update to version 2.4.0+git20230227.0faf846:
  * Disallow a space in rpmlint issue name
  * Unify D-Bus check name
  * FilesCheck: fix typo and shorten setuid/setgid check
  * Revert "Disable Mageia CI builds due to system problem"
  * Disable Mageia CI builds due to system problem
  * Revert "disable opensuse-tumbleweed-aarch64 due to system crash"
* Tue Feb 14 2023 mliska@suse.cz
- Update to version 2.4.0+git20230214.1bab129:
  * Add stopwatch counter for libmagic
  * Support filtering of warnings/errors based on title
  * openSUSE/users-groups: kismet (bsc#1207654)
* Mon Feb  6 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230206.a2c4626:
  * dbus-service: adjust sssd-dbus infopipe whitelisting to /usr (bsc#1207586)
  * d-bus services: adjust NetworkManager-fortisslvpn from /etc to /usr (bsc#1207585)
  * dbus-services: adjust pulseaudio to new /usr path (bsc#1207584)
* Wed Jan 25 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230125.20e5b58:
  * SymlinkExceptions: also exclude systemd-mini
  * FileDigestCheck: allow multiple package names in ghost/symlink exceptions
* Tue Jan 24 2023 mliska@suse.cz
- Update to version 2.4.0+git20230124.a2050c3:
  * FileDigestCheck: support exceptions to symlink restrictions
  * Revert "temporarily drop badness for sysctl-file-* errors"
* Tue Jan 24 2023 mliska@suse.cz
- Update to version 2.4.0+git20230124.a959d84:
  * temporarily drop badness for sysctl-file-* errors
* Thu Jan 19 2023 wolfgang.frisch@suse.com
- Update to version 2.4.0+git20230119.40d52b0:
  * openSUSE: new whitelisting restriction for sysctl drop-in files (bsc#1174722)
* Wed Jan 18 2023 filippo.bonazzi@suse.com
- Update to version 2.4.0+git20230118.aac2cf3:
  * zypper-plugins whitelist: adjust libzypp-plugin-appdata (bsc#1206836)
  * simplify str.split
  * disable opensuse-tumbleweed-aarch64 due to system crash
* Wed Jan 18 2023 mliska@suse.cz
- Update to version 2.4.0+git20230118.42ed609:
  * Update D-Bus whitelisting for NetworkManager-libreswan (bsc#1206757)
* Fri Jan 13 2023 mliska@suse.cz
- Update to version 2.4.0+git20230112.139edaf:
  * use subprocess.run(..., text=True) instead of stdout.decode()
  * Print number of messages that are filtered out
  * Speed up DuplicatesCheck by shorter messages
* Wed Jan 11 2023 mliska@suse.cz
- Update to version 2.4.0+git20230111.8ae3cb5:
  * Files in /etc/pam.d/ should be moved to /usr
* Wed Jan 11 2023 mliska@suse.cz
- Update to version 2.4.0+git20230111.cd8d2e8:
  * magic: remove python2 support and simplify
  * Remove Python 2 support in generate-isocodes.py
* Tue Jan 10 2023 mliska@suse.cz
- Update to version 2.4.0+git20230110.6b6e36c:
  * Use badge for entire devel package in OBS.
  * zypper-plugins: complement test whitelisting by a mismatching entry
* Fri Jan  6 2023 mliska@suse.cz
- Update to version 2.4.0+git20230106.738df37:
  * speed up parsing of ElfSectionInfo
* Fri Jan  6 2023 mliska@suse.cz
- Update to version 2.4.0+git20230106.c39f6c2:
  * Relax no-binary and noarch-with-lib64 checks
* Fri Jan  6 2023 mliska@suse.cz
- Update to version 2.4.0+git20230106.ba0020a:
  * Update openSUSE's licenses.toml
  * Franklin Street address is ok
* Thu Jan  5 2023 mliska@suse.cz
- Update to version 2.4.0+git20230105.c9a861d:
  * openSUSE: new whitelisting restriction for zypper plugins (bsc#1204314)
  * Update D-Bus whitelisting for NetworkManager-iodine (bsc#1206756)
  * Add OBS badge.
* Tue Dec 20 2022 mliska@suse.cz
- Update to version 2.4.0+git20221220.12af927:
  * pam-modules: pam_unix: adjust package name to pam (bsc#1206485)
  * dbus-services: sddm: adjust to configuration file moved from /etc to /usr/share
  * Start using new ruff linter.
* Fri Dec  9 2022 mliska@suse.cz
- Update to version 2.4.0+git20221209.975098b:
  * dbus-services: whitelist transaction-update-notifier (bsc#1206163)
  * Remove for now LGTM badges as it will be closed.
* Wed Dec  7 2022 mliska@suse.cz
- Update to version 2.4.0+git20221206.f05dc9c:
  * dbus-services: /etc -> /usr move for lightdm whitelisting (bsc#1205939)
* Thu Dec  1 2022 mliska@suse.cz
- Update to version 2.4.0+git20221201.82b8b0c:
  * Remove shared-library-without-dependency and library-not-linked-against-libc
* Mon Nov 28 2022 mliska@suse.cz
- Update to version 2.4.0+git20221128.b71453b:
  * PythonCheck: Allow tests folder in python packages
* Tue Nov 22 2022 mliska@suse.cz
- Update to version 2.4.0+git20221122.a31cc76:
  * pam-modules whitelist: add pam_saslauthd (bsc#1205459)
* Tue Nov 22 2022 mliska@suse.cz
- Update to version 2.4.0+git20221122.836c918:
  * dbus-services: whitelist experimental YaST installer D-Bus backend (bsc#1202059)
* Thu Nov 17 2022 mliska@suse.cz
- Update to version 2.4.0+git20221117.15e61cc:
  * Remove Python entries from Filelist checks.
  * GitHub Action: remove --security-opt in action
* Tue Nov 15 2022 mliska@suse.cz
- Update to version 2.4.0+git20221115.3d27dda:
  * PythonCheck: Do not allow tests folder in subpackages (#961)
* Tue Nov 15 2022 mliska@suse.cz
- Update to version 2.4.0+git20221115.32b20b2:
  * Add python check (#955)
* Tue Nov 15 2022 mliska@suse.cz
- Update to version 2.4.0+git20221114.9c41868:
  * codeql: remove cron and use it only for some branches
  * Add CodeQL workflow for GitHub code scanning
* Thu Nov 10 2022 mliska@suse.cz
- Update to version 2.4.0+git20221110.f8919c6:
  * Set DuplicatesMinSize default value to 2
  * dump_stats.py: add one more category for filtering
  * Do not consider files-duplicate for SMALL files
  * SpecCheck: Add python_sitelib glob check
  * remove bugbear exception (B023)
* Fri Oct 28 2022 mliska@suse.cz
- Update to version 2.4.0+git20221028.5eac7b1:
  * SpecCheck: Add python_sitelib glob check
  * dbus-service whitelist: move NetworkManager-openconnect to /usr (bsc#1204795)
* Fri Oct 28 2022 mliska@suse.cz
- Update to version 2.4.0+git20221025.93c4f05:
  * Add python-module-def check to SpecCheck
* Mon Oct 24 2022 mliska@suse.cz
- Update to version 2.4.0+git20221024.648726f:
  * Update the Python module regex to also match stable ABI names
  * update checkout action to v3
* Fri Oct 21 2022 mliska@suse.cz
- Update to version 2.4.0+git20221019.c1d68e9:
  * add pyupgrade to CI
  * format with pyupgrade --py38-plus
* Tue Oct 18 2022 mliska@suse.cz
- Update to version 2.4.0+git20221018.6c36ccd:
  * FilesCheck: Split big check method
* Tue Oct 18 2022 mliska@suse.cz
- Update to version 2.4.0+git20221018.ac9f2d8:
  * SpecCheck: Split big line by line for-loop in methods
  * rpmdiff: clarify help text on -i/-e options
* Fri Oct 14 2022 mliska@suse.cz
- Update to version 2.4.0+git20221014.b4aaa76:
  * Whitelist /var/spool/mail in postfix-bdb (bsc#1179574)
  * dbus-services: document recent follow-up review of cups helpers
  * FileDigestCheck: print digest hint for all possible filter types
  * geoclue2: move dbus system.d file to /usr (bsc#1204054)
  * iio-sensor-proxy: move dbus system.d file to /usr (bsc#1204055)
  * gdm: move dbus system.d file to /usr (bsc#1204052)
* Sat Oct  8 2022 mliska@suse.cz
- Update to version 2.4.0+git20221008.1532b6e:
  * fix broken regex for no-manual-page-for-binary check
  * rpmdiff: improve help for multiple values with -i/-e options
* Tue Oct  4 2022 mliska@suse.cz
- Update to version 2.4.0+git20221004.e71a7e7:
  * sendmail: whitelisting for new systemd-tmpfiles entries for /run, /run/sendmail (bsc#1203340)
* Mon Oct  3 2022 mliska@suse.cz
- Update to version 2.4.0+git20221003.7eb4092:
  * Release 2.4.0.
* Mon Oct  3 2022 mliska@suse.cz
- Update to version 2.4.0+git20220929.9612681:
  * Fix flake8 issue.
* Thu Sep 29 2022 mliska@suse.cz
- Update to version 2.3.0+git20220929.30237f7:
  * Fix test.
* Thu Sep 29 2022 mliska@suse.cz
- Update to version 2.3.0+git20220929.abe3ab9:
  * Add python-setup-test check to SpecCheck
* Wed Sep 21 2022 mliska@suse.cz
- Update to version 2.3.0+git20220921.4e46a84:
  * dbus-services: adjust tuned entry to path move to /usr (bsc#1202339)
* Fri Sep 16 2022 mliska@suse.cz
- Update to version 2.3.0+git20220916.67eb412d:
  * dbus-services: autofs: file digests (bsc#1203362)
  * fix bugzilla url as novell.com is dead
  * Whitelist /var/spool/mail in postfix, sendmail and exim (bsc#1179574)
* Wed Sep 14 2022 Martin Liška <mliska@suse.cz>
- Update to version rpmlint-2.3.0+git20220914.1a7345a1:
  * Whitelist /var/spool/mail in postfix, sendmail and exim (bsc#1179574)
* Tue Sep 13 2022 mliska@suse.cz
- Update to version 2.3.0+git20220913.d905dc70:
  * dbus-services: autofs: move from /etc to /usr
* Tue Sep 13 2022 mliska@suse.cz
- Update to version 2.3.0+git20220913.c8d069d7:
  * dbus-services: adjust/extend kdiskmark whitelisting (bsc#1202725)
* Tue Sep 13 2022 mliska@suse.cz
- Update to version 2.3.0+git20220913.bb2ec481:
  * no-library-dependency-on: consider %%_isa dependencies
  * configs/Fedora: sync user/groups with setup-2.14.1
* Thu Sep  8 2022 mliska@suse.cz
- Update to version 2.3.0+git20220907.165f9c76:
  * Fix a flake8 issue.
  * tools/generate-fedora-users-groups: output in desired format
  * tools/generate-fedora-users-groups: skip comment lines
  * non-conffile-in-etc: skip for /etc/ld.so.conf.d/* files
  * Update Fedora config
  * Ignore one bugbear error.
* Thu Sep  1 2022 mliska@suse.cz
- Update to version 2.3.0+git20220901.67701476:
  * fix _check_manpage crash
* Wed Aug 31 2022 mliska@suse.cz
- Update to version 2.3.0+git20220831.4064cfd1:
  * Relax bad-manual-page-folder
* Tue Aug 30 2022 mliska@suse.cz
- Update to version 2.3.0+git20220830.66066a42:
  * extend checks related to manual pages
* Sun Aug 28 2022 mliska@suse.cz
- Update to version 2.3.0+git20220826.38402552:
  * Revert "Temporarily remove fedora:rawhide as it has broken Python stack."
  * Run flake8 directly as pytest-flake8 is broken.
- Rebase disable-flake-and-cov.patch patch.
* Fri Aug 26 2022 mliska@suse.cz
- Update to version 2.3.0+git20220826.4e835ede:
  * Increase badness for missing-hash-section check (boo#1202520).
  * add missing-hash-section check for HASH ELF sections
  * Silent stdout and stderr for appstream-util command.
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Enhance disable-flake.patch to disable-flake-and-cov.patch
- Reflect the requirements from setup.py in the rpm requirements:
  Use tomli until we have python3 = 3.11
* Thu Aug 18 2022 mliska@suse.cz
- Update to version 2.3.0+git20220818.a8685c5d:
  * dbus-services: whitelist systemd-experimental: systemd-oomd (bsc#1202454)
* Fri Aug 12 2022 mliska@suse.cz
- Update to version 2.3.0+git20220812.05423f8d:
  * dbus-services: adjust to system-config-printer /etc -> /usr move (bsc#1202340)
  * dbus-services: adjust to cups-pk-helper /etc -> /usr move (bsc#1202338)
* Mon Aug  8 2022 mliska@suse.cz
- Update to version 2.3.0+git20220808.2a6c0296:
  * Modify format of binary-or-shlib-defines-rpath
* Thu Aug  4 2022 mliska@suse.cz
- Update to version 2.3.0+git20220804.c5a6b057:
  * Whitelist gromox (bsc#1200165)
* Tue Jul 26 2022 mliska@suse.cz
- Update to version 2.3.0+git20220725.94636c5e:
  * Do not use flake8-simplify for testers automatically.
  * Add flake8-simplify issues.
* Mon Jul 25 2022 mliska@suse.cz
- Update to version 2.3.0+git20220725.8b1e5f2a:
  * Port 2 usages of toml library to tomli.
  * Port TOML configs to tomli library
* Sun Jul 24 2022 mliska@suse.cz
- Update to version 2.3.0+git20220724.d9fd8cf3:
  * Reflect README with toml library change.
  * Use tomllib from the standard library on Python 3.11+
* Thu Jul 21 2022 mliska@suse.cz
- Update to version 2.3.0+git20220721.32c15c31:
  * dbus-services: really adjust location from etc -> usr
* Fri Jul 15 2022 mliska@suse.cz
- Update to version 2.3.0+git20220715.9ec62e45:
  * Skip shlib-policy-name-error for HPC libraries
* Fri Jul 15 2022 mliska@suse.cz
- Update to version 2.3.0+git20220714.7cb9607:
  * Remove trailing ': x%%' from 'package-with-huge-docs' error
  * Fix useless-provides
  * digest whitelists: remove now redundant sha256 algorithm specification
  * FileDigestCheck: use sha256 digest algorithm by default
  * dbus-services: adjust to PackageKit etc -> usr config file move (bsc#1201347)
  * dbus-services: adjust to cups etc -> usr config file move (bsc#1201346)
  * dbus-services: adjust to avahi etc -> usr config file move (bsc#1201345)
- Remove upstreamed patch skip-rpmlint-for-rpmlint.patch.
* Tue Jul 12 2022 Martin Liška <mliska@suse.cz>
- Update to version 2.3.0+git20220712.761ddf0:
  * Improve syntax validation for digests.
- Add skip-rpmlint-for-rpmlint.patch patch that skip linter
  this package.
* Mon Jul 11 2022 mliska@suse.cz
- Update to version 2.3.0+git20220711.46e6323:
  * systemd-tmpfiles: drop version from libtss2-fapi1 filename
* Thu Jul  7 2022 mliska@suse.cz
- Update to version 2.3.0+git20220707.07c9067:
  * Add temporary workaround for systemd package.
  * dbus-services: adjust power-profiles-daemon to new path (bsc#1201125)
* Thu Jun 23 2022 mliska@suse.cz
- Update to version 2.3.0+git20220623.5aa24e0:
  * checkbashism: fix stuck when run with Emacs
  * Add test for shell var detection in rpm-buildroot-usage
  * Fix rpm_buildroot_regex
  * Remove obsolete check no-cleaning-of-buildroot
  * Improve binary-or-shlib-defines-rpath error
  * Add `--file` as an alias for `--rpmlintrc`
  * Update shlib-policy-name-error score for openSUSE
* Wed Jun 15 2022 mliska@suse.cz
- Update to version 2.3.0+git20220615.aa4b7e2:
  * Rework format reporting for shlib-policy-name-error.
  * Increase badness for binary-or-shlib-defines-rpath.
  * Revert "Use zypper for openSUSE."
  * Update shlib-policy-name-error score for openSUSE
* Fri Jun 10 2022 matthias.gerstner@suse.com
- Update to version 2.3.0+git20220610.33ea0cf:
  * systemd-tmpfiles whitelisting: also ignore -mini variants of systemd and udev
  * dbus-services: move wpa_supplicant.conf to /usr
  * dbus-services: move dnsmasq.conf to /usr
* Thu Jun  9 2022 matthias.gerstner@suse.com
- Update to version 2.3.0+git20220609.905726e:
  * systemd-tmpfiles check: raise badness to 10000 for strict config
  * systemd-tmpfiles: whitelist currenty set of affected packages
  * SystemdTmpfilesCheck: compare normalized lines for whitelistings
* Wed May 25 2022 mliska@suse.cz
- Update to version 2.3.0+git20220525.d213f48:
  * opensuse config: parse ValidLicenseExceptions
  * Report binary in shlib-policy-name-error error
  * Remove extra prints from tests.
  * Increase badness for executable-stack
- Remove disable-SystemdTmpfilesCheck.patch.
* Mon May 23 2022 Martin Liška <mliska@suse.cz>
- Add temporary patch disable-SystemdTmpfilesCheck.patch in order to build
  rpmlint with older rpmlint-mini.
* Mon May 23 2022 mliska@suse.cz
- Update to version 2.3.0+git20220523.e71c7f8:
  * SystemdTmpfilesCheck: add additional unit test for parsing logic
  * SystemdTmpfilesCheck: fix invalid member accesses
  * openSUSE: Do not allow files in /etc/NetworkManager/dispatcher.d anymore
* Fri May 20 2022 mliska@suse.cz
- Update to version 2.3.0+git20220519.82b9e76:
  * Release 2.3.0
  * Skip shared-library-without-dependency-information for python.
  * Skip undefined-non-weak-symbol for python packages.
  * SystemdTmpfilesCheck: new check to restrict systemd-tmpfiles configuration.
  * Skip undefined-non-weak-symbol for python packages.
* Fri May 13 2022 mliska@suse.cz
- Update to version 2.2.0+git20220511.fc030cd:
  * Add missing dependencies to setup.py
  * no-binary for all packages
  * Update docs about rpmlintrc auto-loading.
* Mon May  9 2022 mliska@suse.cz
- Update to version 2.2.0+git20220509.ea27381:
  * Fix wrong git merge conflict resolution.
  * ErlangCheck: remove unneeded str() from the test
* Fri May  6 2022 mliska@suse.cz
- Update to version 2.2.0+git20220506.414c402:
  * Temporarily disable binary-or-shlib-defines-rpath once boo#1199268 gets fixed
  * dbus-services: update tukitd config hash to latest reviewed version
* Tue May  3 2022 mliska@suse.cz
- Update to version 2.2.0+git20220503.b807a0d:
  * dbus-services.toml: adjust whitelisting for switcheroo-control (bsc#1199065)
* Mon May  2 2022 mliska@suse.cz
- Update to version 2.2.0+git20220502.c9ee67e:
  * Resolve $ORIGIN in binary-or-shlib-defines-rpath check.
  * Remove empty lines after for loops.
* Tue Apr 26 2022 mliska@suse.cz
- Update to version 2.2.0+git20220425.0078554:
  * Fix up binary-or-shlib-defines-rpath error
* Sat Apr 23 2022 mliska@suse.cz
- Update to version 2.2.0+git20220422.43144bd:
  * Improve executable-stack error.
* Tue Apr 19 2022 mliska@suse.cz
- Update to version 2.2.0+git20220419.1dbd1ae:
  * dbus-services: remove gconf-polkit entry which is no longer shipped in Factory
  * Distinguish exit code in --strict mode.
  * Remove FIXME as we have a test for it.
* Wed Apr 13 2022 mliska@suse.cz
- Update to version 2.2.0+git20220413.2dafaf8:
  * Add ergo user and group
* Mon Apr 11 2022 mliska@suse.cz
- Update to version 2.2.0+git20220411.c02b482:
  * sudoers-whitelist: add another integration test whitelisting entry
* Wed Apr  6 2022 mliska@suse.cz
- Update to version 2.2.0+git20220406.bcfe5ad:
  * sudoers whitelist: add preliminary ceph whitelisting (bsc#1196141)
* Thu Mar 31 2022 mliska@suse.cz
- Update to version 2.2.0+git20220331.762044d:
  * Port opensuse checks.
  * Additional name cleanup in pkg.py.
  * lint.py: remove _check_valid_suffix and use str in ().
  * pkg.py cleanup
  * sudoers whitelist: add test entry for rpmlint-integration-test OBS package
  * Re-init AlternativesCheck for each package.
* Wed Mar 30 2022 mliska@suse.cz
- Update to version 2.2.0+git20220330.4d069ea:
  * new whitelist restriction for /etc/sudoers.d (bsc#1172785)
* Wed Mar 30 2022 mliska@suse.cz
- Update to version 2.2.0+git20220330.76fbb53:
  * Re-init AlternativesCheck for each package.
* Sat Mar 26 2022 mliska@suse.cz
- Update to version 2.2.0+git20220325.40598ec:
  * dbus-services: whitelist usbguard (bsc#1196621)
* Thu Mar 24 2022 mliska@suse.cz
- Update to version 2.2.0+git20220324.fe80080:
  * Test again for non-breaking space in test_tags.py.
  * dbus-services: add missing config whitelist for tukitd (bsc#1196149)
* Wed Mar 23 2022 mliska@suse.cz
- Update to version 2.2.0+git20220323.1c77669:
  * Enhance --time-report
  * dbus services: adjust to accountsservice path move (bsc#1197354)
  * dbus services: NetworkManager-vpnc config locations (bsc#1197053)
  * dbus services: adjust NetworkManager-pptp config locations (bsc#1197054)
  * Use zypper for openSUSE.
  * Add SUSE version checks in spec files (#292).
* Tue Mar 22 2022 mliska@suse.cz
- Update to version 2.2.0+git20220322.91ea8dc:
  * Remove garbage chars (c2a0 c2a0) from file.
  * Add only small badge for repology.
  * Add packaging status.
* Wed Mar  9 2022 mliska@suse.cz
- Update to version 2.2.0+git20220308.a867f4a:
  * test_whitelist_syntax: extend the check to cover also digest entry structure
  * dbus whitelist: fix nodigests whitelisting, should contain the path
  * Remove extra empty lines.
* Mon Mar  7 2022 mliska@suse.cz
- Update to version 2.2.0+git20220307.795b565:
  * D-Bus whitelistings: kpmcore: don't couple service file to digest
* Thu Mar  3 2022 mliska@suse.cz
- Update to version 2.2.0+git20220303.8fe2218:
  * missing alpha_3 hye added for Armenian
* Thu Mar  3 2022 matthias.gerstner@suse.com
- Update to version 2.2.0+git20220303.3a948f5:
  * D-Bus services whitelist: add kpmcore (bsc#1178848)
  * dbus-services whitelist: add test whitelisting to cover dbus-file-parse-error
  * tests: add test that verifies security whitelisting syntax
  * security whitelistings: harmonize bug list syntax
* Tue Mar  1 2022 mliska@suse.cz
- Update to version 2.2.0+git20220228.7070352:
  * FileDigestCheck: configure digest filter type per whitelisting entry
  * FileDigestCheck: also assert that a path key is present
  * dbus-services: adjust nm-priv-helper path (bsc#1194799)
  * dbus-services: whitelist nvme-stas (bsc#1195236)
  * FileDigestCheck: enable XML filtered digests for D-Bus services
  * FileDigestCheck: emit special {group}-file-parse-error if XML is bad
* Fri Feb 25 2022 mliska@suse.cz
- Update to version 2.2.0+git20220225.739a708:
  * a8aa5cb3 pam-modules: whitelist pam-fscrypt (bsc#1195623)
  * ace7a9af dbus-services: whitelist nvme-stas (bsc#1195236)
  * b4d67b66 FileDigestCheck: enable XML filtered digests for D-Bus services
  * 068981ae FileDigestCheck: emit special {group}-file-parse-error if XML is bad
  * 816017cb dbus-services: whitelist tukitd (bsc#1196149)
  * 67c21c1e dbus-services: whitelist kcron helper
* Wed Feb 23 2022 mliska@suse.cz
- Update to version 2.2.0+git20220223.8f7d3e1:
  * Speed up pkg.grep by utilizating mmap.
  * Update package dependency name.
* Tue Feb 22 2022 mliska@suse.cz
- Update to version 2.2.0+git20220222.b4654f9:
  * Small tweaks to report formatting.
  * Start with the biggest files first in BashismsCheck.
  * Add new option --checks.
* Mon Feb 21 2022 mliska@suse.cz
- Update to version 2.2.0+git20220221.0fec15f:
  * Speed up BashismsCheck by using md5sum of file.
* Mon Feb 21 2022 mliska@suse.cz
- Update to version 2.2.0+git20220221.19e374d:
  * Include rpm2cpio (decompression and extraction) in --time-report.
  * Print only on decimal digit in time report.
  * Speed up pkg.grep.
  * Fix superfluous variable.
* Sun Feb 13 2022 mliska@suse.cz
- Update to version 2.2.0+git20220211.709d2fa:
  * Require at least Python 3.8.
  * FileDigestCheck: implement support for file digest filtering
* Sun Feb  6 2022 mliska@suse.cz
- Update to version 2.2.0+git20220204.4166915:
  * tests: add test case for FileDigestGroup with multiple package names
  * FileDigestCheck: support additional `packages = ["pkg1", "pkg2"]` syntax
  * FileDigestCheck: refactor digest group parsing and normalization
  * FileMetadataCheck: support additional `packages = ["pkg1", "pkg2"]` syntax
* Wed Feb  2 2022 mliska@suse.cz
- Update to version 2.2.0+git20220202.cf37318:
  * pam-modules: remove now outdated entry for modules that moved into pam_unix
* Thu Jan 27 2022 Martin Liška <mliska@suse.cz>
- Update to version 2.2.0+git20220127.05573d9:
  * dbus-services: whitelist NetworkManager nm-priv-helper (bsc#1194799).
* Tue Jan 25 2022 mliska@suse.cz
- Update to version 2.2.0+git20220125.7caec47:
  * Add new option --ignore-unused-rpmlintrc.
* Sat Jan 22 2022 mliska@suse.cz
- Update to version 2.2.0+git20220121.4f4f673:
  * Remove shared-library-not-executable for all shared libs.
  * Fix stupid mistake with shared-library-not-executable.
  * Remove duplicite argument for run_elf_checks and use PkgFile.
  * Set also LANGUAGE env. in ENGLISH_ENVIROMENT.
  * Fix LGTM warning about RE pattern.
* Thu Jan 13 2022 mliska@suse.cz
- Update to version 2.2.0+git20220112.bfaf91a:
  * pam module whitelist: adjust package name for pam_winbind (bsc#1194573)
* Fri Jan  7 2022 mliska@suse.cz
- Update to version 2.2.0+git20220106.43867d0:
  * Use readelf --debug-dump=no-follow-links if available.
  * Do not use ObjdumpParser if not needed.
  * Add icingaweb2 group
  * Filter unused-rpmlintrc-filter for late checks.
* Wed Jan  5 2022 mliska@suse.cz
- Update to version 2.2.0+git20220105.2ac5ee1:
  * Use different Python package for ZStandard
* Mon Jan  3 2022 mliska@suse.cz
- Update to version 2.2.0+git20220103.bda86d8:
  * 64-bit powerpc targets do not have executable stack.
* Tue Dec 21 2021 mliska@suse.cz
- Update to version 2.2.0+git20211221.2fbc146:
  * fix connman-nmcompat whitelisting (bsc#1192827) - resides in a sub-package
* Thu Dec 16 2021 mliska@suse.cz
- Update to version 2.2.0+git20211216.95ed862:
  * Do not expect precise order of suggestions in spellchecking.
* Thu Dec 16 2021 mliska@suse.cz
- Update to version 2.2.0+git20211215.5196826:
  * Make missing-call-to-setgroups-before-setuid only warning.
* Mon Dec 13 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Fri Dec 10 2021 Martin Liška <mliska@suse.cz>
- Update tarball naming to respect release version.
* Fri Dec 10 2021 matthias.gerstner@suse.com
- Update to version 2.2+git20211210.51d1bd9:
  * dbus-services whitelist: add connman nm compatibility interface (bsc#1192827)
* Wed Dec  8 2021 mliska@suse.cz
- Update to version 2.2+git20211208.c7ec6c4:
  * Fix typo in comment.
  * Release 2.2.0
  * configs/Fedora: Sync Fedora rpmlint policies back upstream
* Tue Nov 30 2021 mliska@suse.cz
- Update to version 2.1+git20211130.83af44b:
  * Add SUSE licenses generation script.
  * Sort input .rpm files so that the output is stable. (boo#1193189).
* Fri Nov 26 2021 mliska@suse.cz
- Update to version 2.1+git20211126.ebc84d5:
  * allow rpmdiff for installed packages
  * Add diff.py wrapper script.
* Fri Nov 26 2021 mliska@suse.cz
- Update to version 2.1+git20211125.fcbf5ab:
  * Make missing-PT_GNU_STACK-section more sensitive.
* Tue Nov 23 2021 mliska@suse.cz
- Update to version 2.1+git20211122.36cebbc:
  * dbus-services: fix package name for setroubleshoot entries
* Sat Nov 20 2021 mliska@suse.cz
- Update to version 2.1+git20211118.f21c64f:
  * duplicate postfix entry for postfix-bdb, whitelistings are tied to pacakges in rpmlint2 and need to be there for every package
  * Allow multiple spaces between paren
* Mon Nov 15 2021 mliska@suse.cz
- Update to version 2.1+git20211113.372a30e:
  * Misplaced spaces causes regex to not match.
  * Add debuginfod user and update message.
* Wed Nov 10 2021 mliska@suse.cz
- Update to version 2.1+git20211110.8430dc4:
  * polkit-rules-whitelist: follow-up whitelisting for gnome-initial-setup (bsc#1192542)
* Wed Nov 10 2021 mliska@suse.cz
- Update to version 2.1+git20211109.f2e93f8:
  * Add missing re.compile.
  * Prevent duplicate files in lint input
* Sat Nov  6 2021 mliska@suse.cz
- Update to version 2.1+git20211105.14a37df:
  * Fix backward compatibility with rpmlintrc files.
  * Fixed bug where a valid symlink is reported as invalid.
    This appears to be a regression from rpmlint 1.
    Comparing the two reveals that the comparison of link
    to path.parent would never make sense, and comparing
    link to path.name would resemble rpmlint 1's behavior.
  * dbus-services: add setroubleshoot whitelisting (bsc#1186344)
* Wed Nov  3 2021 mliska@suse.cz
- Update to version 2.1+git20211103.8d20461:
  * permissions-whitelist: update texlive-filesystem digests
  * permissions-whitelist: update sendmail digests
  * Enhance error message of LibraryDependencyCheck.
* Mon Nov  1 2021 mliska@suse.cz
- Update to version 2.1+git20211101.f2e73fe:
  * Fix no-library-dependency-for.
* Sun Oct 31 2021 mliska@suse.cz
- Update to version 2.1+git20211027.7242d3d:
  * dbus-services: adjust wicked whitelisting to new paths (bsc#1192033)
  * Add new LibraryDependencyCheck.
  * Rework the lib_regex pattern
  * security whitelistings: test whitelistings for file-digest-mismatch errors
  * scoring.toml: fix alphabetical order of permissions-file errors
  * security whitelistings: add badness for file-digest-mismatch errors
* Fri Oct 22 2021 mliska@suse.cz
- Update to version 2.1+git20211022.a5287ad:
  * Mitigate Perl false positives for no-dependency-on.
* Thu Oct 21 2021 mliska@suse.cz
- Update to version 2.1+git20211021.74e867e:
  * Checking libalternatives entries and links.
  * Fix -r argument.
  * opensuse.toml: add permissions-parse-error to BlockedFilters
  * dbus-services: adjust digest for test whitelisting (need a different file there)
  * polkit-rules-whitelist: fix package name for test whitelisting
  * Remove unused VS code settings.
  * Whitelisting pam_u2f module (bsc#1190790)
* Tue Oct 19 2021 mliska@suse.cz
- Update to version 2.1+git20211019.ca2517e:
  * Ignore library names that have number in their names.
* Tue Oct 19 2021 mliska@suse.cz
- Update to version 2.1+git20211018.b53feea:
  * Tweak shlib-policy-name-error.
* Fri Oct 15 2021 mliska@suse.cz
- Update to version 2.1+git20211015.6dc5311:
  * Drop badness of shlib-policy-name-error for now.
* Thu Oct 14 2021 mliska@suse.cz
- Update to version 2.1+git20211014.e3fbbb9:
  * Update shlib-policy-name-error.
* Thu Oct 14 2021 mliska@suse.cz
- Update to version 2.1+git20211014.bddee7c:
  * Trigger shlib-policy-name-error only for lib* packages.
* Thu Oct 14 2021 mliska@suse.cz
- Update to version 2.1+git20211013.5ed66cd:
  * Update wording for shlib-policy-name-error.
  * Fix changelog-time-in-future regarding timezones.
* Tue Oct 12 2021 paolo.perego@suse.com
- Update to version 2.1+git20211012.c27e0fe:
  * Adding whitelisting for pam_ssh_agent_auth. bsc#1190983
* Mon Oct 11 2021 mliska@suse.cz
- Update to version 2.1+git20211011.4290515:
  * Enable shlib-policy-name-error error.
* Mon Oct 11 2021 Martin Liška <mliska@suse.cz>
- Update to version 2.1+git20211011.a28fc6d:
  * Support %%autochangelog in %%changelog.
  * remove /run from disalloweddirs
  * Fix missing-dependency-on check.
  * dbus-services whitelisting: add power-profiles-daemon (bsc#1189900)
  * security whitelistings: add whitelistings for OBS integration test package
  * PolkitCheck: be robust against dead symlinks in actions directory
  * SUIDPermissionsCheck: remove unused permissions-ghostfile error
  * *-file-ghost descriptions: fix texts that are for some reason incomplete
- Fixes boo#1190387.
* Mon Oct 11 2021 Martin Liška <mliska@suse.cz>
- Enable changesgenerate.
* Wed Oct  6 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- Update to opensuse tip:
  * dbus-services: add oddjob-mkhomedir which got lost during migration (bsc#1169494)
* Fri Oct  1 2021 Martin Liška <mliska@suse.cz>
- Update to tip:
  * fix lto-no-text-in-archive for rx port.
* Thu Sep 30 2021 Martin Liška <mliska@suse.cz>
- Updade to opensuse tip:
  * skip %%ghost files in SUIDPermissionsCheck.
* Fri Sep 24 2021 Johannes Segitz <jsegitz@suse.com>
- Update to 2.1+git20210924.ad0cf53
  * Copied additional systemd whitelistings to match systemd-mini
* Thu Sep 23 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.1+git20210923.5ff1403
  * whitelist pam_systemd.so for systemd-mini
* Thu Sep 23 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.1+git20210923.a41591b
  * whitelist pam_systemd_home.so for systemd-experimental
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.1+git20210922.d20a3f1
  * Added mechanism to add exceptions for %%ghost'd files
  * Remove deprecated entries for world-writable entries
  * Remove malcontent whitelisting
  * Remove storeBackup cron whitelisting
  * Some path and package name fixes
* Fri Sep 17 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- Synchronize security whitelistings with whitelists from old rpmlint 1. This
  should fix some package build errors like in sssd.
- Use correct camel case package names for packages like NetworkManager in
  whitelists. This should fix some package build errors.
- Some general cleanup of whitelists.
* Wed Sep 15 2021 Martin Liška <mliska@suse.cz>
- Bump to tip (various security fixes).
* Sun Sep  5 2021 Martin Liška <mliska@suse.cz>
- Skip .cargo-checksum.json files in hidden-file-or-dir.
* Thu Sep  2 2021 Martin Liška <mliska@suse.cz>
- Fix PieExecutables matching.
* Thu Sep  2 2021 Martin Liška <mliska@suse.cz>
- KMP policy: support legacy 'packageand' directive in Supplements
  (boo#1190103).
* Wed Sep  1 2021 Martin Liška <mliska@suse.cz>
- Handle empty glibc archives (starting with version 2.34).
* Fri Aug 27 2021 Martin Liška <mliska@suse.cz>
- Update package name for -M test.
* Thu Aug 26 2021 Martin Liška <mliska@suse.cz>
- Add test multibuild target and reduce BuildRequirements for rpmlint
  package itself.
* Wed Aug 25 2021 Martin Liška <mliska@suse.cz>
- Bump to opensuse tip.
* Wed Aug 18 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- whitelist deepin-api D-Bus services (bsc#1070943)
* Wed Aug 18 2021 Martin Liška <mliska@suse.cz>
- Bump to version 2.1.
* Fri Aug  6 2021 Martin Liška <mliska@suse.cz>
- Fix variable description expansion.
* Thu Aug  5 2021 Martin Liška <mliska@suse.cz>
- Reduce Requirements for rpmlint-strict package.
* Wed Aug  4 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- whitelist oddjob-gpupdate PAM and D-Bus (bsc#1188680)
* Thu Jul 22 2021 Martin Liška <mliska@suse.cz>
- Bump to tip (adds --mini-mode argument).
* Thu Jul  1 2021 Martin Liška <mliska@suse.cz>
- Bump to tip (fix not working -i option).
* Tue Jun 29 2021 Martin Liška <mliska@suse.cz>
- Bump to tip.
* Tue Jun 29 2021 Martin Liška <mliska@suse.cz>
- Make rpmlint-strict only a simple package with one config file.
* Tue Jun 29 2021 Martin Liška <mliska@suse.cz>
- Add Conflicts directive.
* Tue Jun 29 2021 Martin Liška <mliska@suse.cz>
- Use BuildIgnore: rpmlint-strict in order to fix boo#1187749.
* Fri Jun 25 2021 Martin Liška <mliska@suse.cz>
- Bump to tip.
- Rename scoring-strict.toml to scoring-strict.override.toml in order
  to use override mechanism.
* Thu Jun 24 2021 Martin Liška <mliska@suse.cz>
- Removed legacy patches:
  * extend-suse-conffiles-check.diff
  * docdata-examples.diff
  * devel-provide-is-devel-package.diff
  * fix-diag-sortorder.diff
  * check-for-self-provides.diff
- Add disable-flake.patch patch.
* Thu Jun 24 2021 Martin Liška <mliska@suse.cz>
- Add rpmlint-strict sub-package that includes scoring-strict.toml.
* Thu Jun 24 2021 Martin Liška <mliska@suse.cz>
- Bump to tip: adds scoring-strict.toml config and BlockedFilters.
* Thu Jun 24 2021 Martin Liška <mliska@suse.cz>
- Bump to tip, includes fix for Rust libraries.
* Thu Jun 17 2021 Martin Liška <mliska@suse.cz>
- Install configs with 644.
* Thu May 27 2021 Martin Liška <mliska@suse.cz>
- Update to Rpmlint 2.0:
  * RPMLint now is a "normal" Python application and now supports being imported
    like a standard Python module! This means that all the normal use-cases for
    RPMLint are still supported, but now you can make it a part of larger Python-based
    applications or services.
  * RPMLint uses a declarative TOML-based syntax for configuring RPMLint policy
    instead of Python code.
  * RPMLint now has an override system for the descriptions shown for various checks,
    so that distributions who want to give specific policy information can
    do so without patching the code.
  * RPMLint includes many more checks! Nearly all of the generally useful checks created
    by the openSUSE community have been merged into the tree, so distributions can now
    benefit from a wider offering of checks to implement policy enforcement.
  * RPMLint is Python 3 only and now supports Python 3.6 and newer.
  * RPMLint is now built and installed like a standard Python application using setuptools.
- Removed legacy patches:
  * invalid-filerequires.diff
  * no-badness-return.diff
  * no-doc-for-lib.diff
  * only-reg-files-are-scripts.diff
  * remove-ghostfile-checks.diff
  * rpm415-workaround.diff
  * rpmgroup-checks.diff
  * rpmlint-suse.diff
  * suse-binarieschecks.diff
  * suse-checks.diff
  * suse-filter-exception.diff
  * suse-filter-more-verbose.diff
  * suse-ignore-specfile-errors.diff
  * suse-pkg-config-check.diff
  * suse-python3-naming-policy.diff
  * suse-shlib-devel-dependency.diff
  * suse-skip-macro-expansion.diff
  * suse-speccheck-utf8.diff
  * suse-url-check.diff
  * suse-version.diff
  * yast-provides.diff
  * 0001-ZipCheck-Also-ignore-RuntimeError.patch
  * accept-licenses-with-plus.patch
  * add-check-for-a-non-zero-.text-segment-in-.a-archive.patch
  * rpmlint-slpp-NUM-NUM.patch
  * rpmlint-tests-sle15.patch
  * suse-rpmlint-all-pie.patch
  * suse-spdx-license-exceptions.patch
  * suse-tests-without-badness.patch
- Removed config fileS:
  * config
  * licenses.config
  * pie.config
- Removed misc files: syntax-validator.py, README.packaging.txt,
  rpmlint-1.11.tar.gz, rpmlint-checks-master.tar.xz and
  rpmlint-tests-84.87+git20210226.d6b66e2.tar.xz.
* Fri May 21 2021 Ludwig Nussel <lnussel@suse.de>
- whitelist setroubleshoot (boo#1186344)
* Wed May 12 2021 Ludwig Nussel <lnussel@suse.de>
- whitelist systemd-homed (boo#1185285)
* Fri May  7 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- fix whitelisting for kdiskmark service (bsc#1182521)
* Wed Mar 31 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- whitelist D-Bus Service org.kde.filesharing.samba.service (bsc#1175633)
* Tue Mar 30 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- whitelist D-Bus Service org.jonmagon.kdiskmark.service (bsc#1182521)
* Fri Feb 26 2021 Stephan Kulow <coolo@suse.com>
- Add accept-licenses-with-plus.patch to accept any license ending
  with a + (as indicated in the SPDX syntax)
* Fri Feb 26 2021 Stephan Kulow <coolo@suse.com>
- Remove licenses ending with + from valid license array
* Mon Feb 22 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- whitelist pam_sss_gss.so PAM module (bsc#1182509)
* Wed Feb  3 2021 chris@computersalat.de
- add 'otobo' group/id
* Mon Feb  1 2021 Stephan Kulow <coolo@suse.com>
- Update valid spdx license exceptions
- Allow the + version of all valid licenses (to avoid having to fix
  the parser)
* Fri Jan 15 2021 Christopher Yeleighton <giecrilj@stegny.2a.pl>
- Fix a typo in suse-branding-wrong-branding-supplement
* Sun Jan 10 2021 Martin Hauke <mardnh@gmx.de>
- Add user "h2o" and group "h2o" for the h2o webserver
* Tue Nov 17 2020 matthias.gerstner@suse.com
- Update to version master:
  * Permissions: be robust against variables.conf not existing
  * CheckSUIDPermissions: enhance parser to support new permissions variables
* Wed Nov  4 2020 Malte Kraus <malte.kraus@suse.com>
- allow pam_faillock.so PAM module (bsc#1171562)
* Fri Oct 30 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- whitelist malcontent PAM module (bsc#1177974)
* Mon Oct 19 2020 Илья Индиго <ilya@ilya.pp.ua>
- Add user "fluidsynth" for FluidSynth General Midi daemon.
* Mon Oct 12 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- whitelist plasma5-disks smartmon helper (bsc#1176742)
* Thu Oct  1 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- whitelist D-Bus files for powerdevil chargethreshold (bsc#1176474)
* Thu Oct  1 2020 Paolo Stivanin <info@paolostivanin.com>
- Add 'gerbera' as standard user and group
* Fri Sep 11 2020 Ákos Szőts <szotsaki@gmail.com>
- Alphabetise StandardGroups and StandardUsers
- Add 'radicale' as a standard user and group
* Fri Aug 14 2020 Marco Strigl <marco.strigl@suse.com>
- add user "jvb", "jibri", "jicofo" and group "jitsi" for Jitsi
  videomeeting service
* Fri Jul 31 2020 matthias.gerstner@suse.com
- Update of rpmlint-checks to version master:
  * Introduce new metadata whitelist type and related checks. Device files and
    world-writeable files will now be covered by new whitelists from
    rpmlint-security-whitelistings.
- config: Enable new CheckWorldWritable and CheckDeviceFiles
* Fri Jul 24 2020 matthias.gerstner@suse.com
- whitelist kanidm PAM module (bsc#1173387)
* Wed Jul 15 2020 matthias.gerstner@suse.com
- whitelist D-Bus files for libvirt-dbus (bsc#1173093)
* Wed Jul  8 2020 Илья Индиго <ilya@ilya.pp.ua>
- Add user and group "ptokax" for PtokaX DC++ hub.
* Fri Jun 19 2020 Egbert Eich <eich@suse.com>
- Add user/group 'conman' and 'munge' and group 'warewulf'.
* Fri Jun 12 2020 cunix@mail.de
- Add 'dnscrypt' to StandardGroups and StandardUsers for package dnscrypt-proxy
* Thu Jun  4 2020 matthias.gerstner@suse.com
- whitelist pam_setquota (bsc#1171563)
* Wed Jun  3 2020 Martin Hauke <mardnh@gmx.de>
- Add '_gns3' to StandardGroups and StandardUsers
* Mon May 25 2020 matthias.gerstner@suse.com
- whitelist pam_usertype (bsc#1171564)
* Wed May 20 2020 Johannes Segitz <jsegitz@suse.de>
- whitelist cockpit PAM modules (bsc#1169614)
  * pam_cockpit_cert
  * pam_ssh_add
* Wed May 20 2020 Adrian Schröter <adrian@suse.de>
- Add daapd user and group for new forked-daapd package
* Tue May 19 2020 Thomas Renninger <trenn@suse.de>
- Add '_cscreen' to StandardGroups and StandardUsers
* Tue May 12 2020 matthias.gerstner@suse.com
  Cleanup of deprecated DBUSServices.WhiteList entries:
- ca.desrt.dconf.service: this service was changed by upstream from a
  system-wide service to a session based service. The latter doesn't require a
  whitelisting any more.
- wicked services (network-nanny.conf, wicked-dhcp4.conf, wicked-dhcp6.conf,
  wicked-autoip4.conf, wicked.conf): these have been renamed in August 2013
  to org.opensuse.Network.*.conf. The old names probably never got released.
- nfs-ganesha.service: A D-Bus file of that name probably never existed,
  there's just a regular systemd unit of that name.
- org.drbd.drbdmanaged.conf, org.drbd.drbdmanaged.service: drbdmanage was just
  recently removed from Factory via sr#798685, because it is Python2 only and
  unmaintained.
- org.freedesktop.NetworkManager.service: was removed in 2012, Factory
  revision 118, `Remove dbus system-service for NetworkManager, to prevent
  warnings about it not being running (bnc#738596)`.
- org.kde.auth.conf: was from kdelibs4, removed from Factory in late 2019 via
  sr#738276 with the rest of kde4.
- org.kde.kcontrol.kcmkdm.conf, org.kde.kcontrol.kcmkdm.service: was part of
  kdebase4-workspace, got deleted from Factory with the rest of kde4.
- org.kde.kcontrol.kcmkwallet.conf, org.kde.kcontrol.kcmkwallet.service: they
  got renamed to kcmkwallet5.
- org.opensuse.openqa.conf: upstream replaced a D-Bus interface with HTTP.
- org.opensuse.zoneswitcher.service, org.opensuse.zoneswitcher.conf: the fwzs
  package got removed together with SuSEfirewall2 via sr#713580.
- org.selinux.service: isn't included any more in our packaging of
  policycoreutils.
- thunderbolt.conf, thunderbolt.service: this service never went live in
  Factory.
- yum-updatesd.conf: yum was removed from Factory via sr#749200
- openattic.conf, openattic.service: was part of SES3 but seems to have
  been dropped from SES4 and newer.
  Cleanup of deprecated PAMModules.WhiteList entries:
- pam_cgroup.so: libcgroup was removed from Factory via sr#589236, due to
  conflicts with systemd and dead upstream.
- pam_ck_connector.so: ConsoleKit was last used in SLE-11. It's long dead.
- pam_cryptpass.so: cryptconfig was last shipped in SLE-12:GA and Leap 42.3.
  Got removed via FATE#323541.
- pam_envoy.so: was removed from Factory because it failed to build for >= 6
  weeks, see sr#737277
- pam_fprint.so: was replaced by fprintd, see delete sr#220831.
- pam-modules package (pam_homecheck.so, pam_pwcheck.so, pam_unix2.so): the
  pam-modules package was removed in 2017 from Factory, see sr#540149.
- pam_mate_keyring.so: was never shipped, the packager switched to a different
  keyring daemon instead.
- pam_p11_opensc.so, pam_p11_openssh.so: these two have been merged into
  pam_p11.so.
- pam_rpasswd.so: was part of pwdutils which was replaced by shadow utilities
  in 2012 via sr#139683.
- pam_smb_auth.so: was last part of SLE-12:GA and Leap 42.3. no upstream
  development, replaced by pam_winbind, see sr#478612
- pam_smbpass.so: was removed in upstream version 4.4.2, because it loaded
  GPLv3 code into the address space of system services. somewhat replaced by
  pam_winbind. see https://bugzilla.redhat.com/show_bug.cgi?id=952766.
- pam_tally.so: was removed from the pam package in 2013, replaced by tally2
  obviously, the old one was buggy.
* Mon May 11 2020 matthias.gerstner@suse.com
- whitelist oddjob D-Bus services and PAM module (bsc#1169494)
* Sun Apr 12 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added 'coturn' to StandardGroups and StandardUsers
* Tue Mar 31 2020 matthias.gerstner@suse.com
- Update to version master:
  * Whitelisting: avoid duplicate checks / error messages for the same files
  * Whitelisting: fix whitelisting checks when files are symbolic links
  * Mention upstream repo in README
* Fri Mar 27 2020 Axel Braun <axel.braun@gmx.de>
- Bug 1167431 - AUDIT-0: User/group orthanc for rpmlint
* Thu Feb 20 2020 Malte Kraus <malte.kraus@suse.com>
- config: enable MixedFileOwnerships lint
* Thu Feb 20 2020 Dr. Werner Fink <werner@suse.de>
- config: add 'mktex' to StandardUsers (boo#1159740)
* Mon Feb 17 2020 matthias.gerstner@suse.com
- whitelist new mariadb pam module "pam_user_map.so" (bsc#1163362)
* Thu Feb  6 2020 malte.kraus@suse.com
- Update to version master:
  * CheckSUIDPermissions.py: fix permissions.d checks
  * add a lint to catch insecure mixed file/directory ownership similar to CVE-2019-3689
* Thu Feb  6 2020 malte.kraus@suse.com
- Update to version 84.87+git20200206.7e2b64f:
  * permissions2: test that allowed permissions.d drop-ins work
  * test for new file-parent-ownership-mismatch lint
* Fri Jan 31 2020 matthias.gerstner@suse.com
- Whitelist a batch of PAM modules that have been forgotted to be whitelisted
  in the past, or have never been requested to be reviewed before
  (bsc#1150178).
  Since we want to add badness to the PAM warning in rpmlint we need to add
  those entries to avoid build errors of existing packages in Factory.
* Thu Jan 30 2020 James Fehlig <jfehlig@suse.com>
- config: add 'sanlock' to StandardGroups and StandardUsers
- config: add 'libvirt' to StandardGroups
* Thu Jan 30 2020 jsegitz@suse.de
- Update to version master:
  * CheckCronJobs: correct cronjob-unauthorized-file explanation
  * Use named constants to check file modes
  * CheckSUIDPermissions.py: check new permission paths
* Wed Dec 18 2019 matthias.gerstner@suse.com
- finally enable the new CheckCronJobs, the check is now available and should
  work in rpmlint-mini (bsc#1150175)
* Mon Dec 16 2019 Nathan Cutler <ncutler@suse.com>
- config: add 'cephadm' to StandardGroups and StandardUsers
* Mon Dec 16 2019 matthias.gerstner@suse.com
- whitelist pam_cgfs PAM module (bsc#1150519)
* Mon Dec 16 2019 matthias.gerstner@suse.com
- whitelist pam_pwquality PAM module (bsc#1150520)
* Mon Dec 16 2019 matthias.gerstner@suse.com
- whitelist pam_cifscreds PAM module (bsc#1150527)
* Tue Dec 10 2019 matthias.gerstner@suse.com
- Update to version master:
  * new common whitelisting code for CheckPolkitPrivs and CheckCronJobs
* Thu Nov 28 2019 Malte Kraus <malte.kraus@suse.com>
- whitelist sssd infopipe (bsc#1157663)
- whitelist sysprof3 D-Bus services (bsc#1151418)
* Tue Oct 15 2019 Ludwig Nussel <lnussel@suse.de>
- filter install-info warnings. Handled by file triggers now (boo#1152169)
* Mon Oct  7 2019 mls@suse.de
- backport rpm415 workaround from upstream
  new patch: rpm415-workaround.diff
* Mon Sep 30 2019 Ondřej Súkup <mimi.vx@gmail.com>
-  update add-check-for-a-non-zero-.text-segment-in-.a-archive.patch
  * fix condition for path
* Fri Sep 20 2019 Malte Kraus <malte.kraus@suse.com>
- whitelist pam_envoy (bsc#1150525)
* Fri Sep 20 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update add-check-for-a-non-zero-.text-segment-in-.a-archive.patch
  * dont check empty .text section on GHC libraries
* Tue Sep 17 2019 dmueller@suse.com
- Update rpmlint-checks to version master:
  * CheckFilelist: Add /usr/libexec to set of good prefixes
* Wed Aug 28 2019 tchvatal@suse.com
- Update to version 84.87+git20190828.2c92180:
  * Revert "added LTO errors as expected for debug tests"
* Wed Aug 28 2019 tchvatal@suse.com
- Update to version 84.87+git20190828.8fa8ac5:
  * Do not use -flto for debug tests.
* Wed Aug 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not validate rpm groups to avoid rpmlint warning as the group
  is not really mandatory (fate#326485)
* Thu Aug 22 2019 Ludwig Nussel <lnussel@suse.de>
- whitelist systemd-portabled dbus files (boo#1145639)
* Tue Aug 20 2019 kukuk@suse.com
- Update to version master:
  * Allow /usr/etc as discussed on opensuse-factory and opensuse-packaging
* Wed Aug 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- Add user/group zabbix and zabbixs (bsc#1144018)
* Fri Aug  9 2019 Martin Liška <mliska@suse.cz>
- Update add-check-for-a-non-zero-.text-segment-in-.a-archive.patch patch to align with:
  38fc30cafe99d38059ca54b98bc87f5544f0bb4e
* Thu Aug  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Add Development/Languages/Go group.
* Thu Aug  8 2019 Martin Liška <mliska@suse.cz>
- Update add-check-for-a-non-zero-.text-segment-in-.a-archive.patch patch to align with:
  80126f7c7854d962cc64e54a6ab7e97067bb490d
* Fri Aug  2 2019 Martin Liška <mliska@suse.cz>
- Update add-check-for-a-non-zero-.text-segment-in-.a-archive.patch patch to align with:
  https://github.com/rpm-software-management/rpmlint/commit/c59324fd68ba86c8382fe09d43f12de32d764354
* Sun Jul 28 2019 Martin Liška <mliska@suse.cz>
- Update add-check-for-a-non-zero-.text-segment-in-.a-archive.patch patch
  to:
  https://github.com/rpm-software-management/rpmlint/commit/97d6caf9ac3eb011e3f30dbc473f079b20fb56f9
* Mon Jul 22 2019 Martin Liška <mliska@suse.cz>
- Add add-check-for-a-non-zero-.text-segment-in-.a-archive.patch
  as a backport of:
  https://github.com/rpm-software-management/rpmlint/commit/2c809f34354d6ea690986541b268d47a3ca59092
* Tue May 14 2019 opensuse-packaging@opensuse.org
- Update to rpmlint-checks to version master:
  * CheckDBUSServices: add additional directory to cover
  * Xinetd check making sure no packages use it wrt fate#323373 (#26)
* Wed May  8 2019 jsegitz@suse.com
- Too trigger happy, adding back
  * ca.desrt.dconf.service
  * org.freedesktop.ColorManager.conf
* Wed May  8 2019 jsegitz@suse.com
- Removed whitelisted DBUS files:
  * ConsoleKit.conf
  * NetworkManager-frontend.conf
  * Upstart.conf
  * backup-manager.conf
  * ca.desrt.dconf.service
  * cdemud-dbus.conf
  * com.redhat.storaged.conf
  * com.redhat.storaged.service
  * com.redhat.tuned.service
  * de.berlios.smb4k.mounthelper.conf
  * de.berlios.smb4k.mounthelper.service
  * hal.conf
  * kerneloops.dbus
  * net.hadess.SensorProxy.service
  * nm-avahi-autoipd.conf
  * nm-dhcp-client.conf
  * nm-novellvpn-service.conf
  * openqa-scheduler.service
  * openqa-websockets.service
  * org.blueman.Applet.service
  * org.freedesktop.ColorManager.conf
  * org.freedesktop.ConsoleKit.service
  * org.freedesktop.ModemManager.conf
  * org.freedesktop.ModemManager.service
  * org.freedesktop.PolicyKit.conf
  * org.freedesktop.PolicyKit.service
  * org.freedesktop.UDisks.conf
  * org.freedesktop.UDisks.service
  * org.freedesktop.colord-sane.conf
  * org.freedesktop.colord-sane.service
  * org.gnome.SettingsDaemon.DateTimeMechanism.conf
  * org.gnome.SettingsDaemon.DateTimeMechanism.service
  * org.kde.baloo.filewatch.conf
  * org.kde.baloo.filewatch.service
  * org.kde.kalarmrtcwake.conf
  * org.kde.kalarmrtcwake.service
  * org.kde.kcontrol.k3bsetup.conf
  * org.kde.kcontrol.k3bsetup.service
  * org.kde.kcontrol.kcmlightdm.conf
  * org.kde.kcontrol.kcmlightdm.service
  * org.kde.kcontrol.kcmremotewidgets.conf
  * org.kde.kcontrol.kcmremotewidgets.service
  * org.kde.nepomuk.filewatch.conf
  * org.kde.nepomuk.filewatch.service
  * org.kde.polkitkde1.helper.conf
  * org.kde.polkitkde1.helper.service
  * org.neard.service
  * org.opensuse.BackupManager.service
  * org.opensuse.YaST.modules.conf
  * org.opensuse.YaST.modules.service
  * org.opensuse.usbauth.service
  * org.opensuse.yast.SCR.conf
  * org.opensuse.yast.SCR.service
  * org.selinux.conf
  * org.synce.dccm.conf
  * org.synce.dccm.service
  * os-autoinst-openvswitch.service
  * pam_dbus.service
  * podsleuth.conf
  * rebootmgr.service
  * switcheroo-control.service
  * teamd@.service
  * webyast.permissions.conf
  * webyast.permissions.service.service
  They're not used anymore in current products, were never active or erroneously
  added. For details please see
  https://pes.suse.de/Maintenance-Security/Whitelists/cleanup_dbus/
* Tue May  7 2019 Malte Kraus <malte.kraus@suse.com>
- Whitelisted certmonger (bsc#1129452)
* Fri Apr 12 2019 Thomas Bechtold <tbechtold@suse.com>
- Add missing usernames for OpenStack services and drop the old
  names (which had the openstack- prefix)
* Tue Mar  5 2019 mvetter@suse.com
- Add user/group 'minetest' for Minetest 5.0.0 (bsc#1127911)
* Mon Mar  4 2019 opensuse-packaging@opensuse.org
- Update to version master:
  * CheckPolkitPrivs: fix new rules.d check to use extracted rpm path
* Wed Feb 27 2019 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master (bsc#1125314):
  * coding style: fix indentation to satisfy flake8 travis-ci test
  * CheckPolkitPrivs: implement new check for files put into rules.d dirs
  * CheckPolkitPrivs: separate and refactor check for actions
  * CheckPolkitPrivs: separate and refactor check of polkit-default-privs.d
  * CheckPolkitPrivs: remove oudated PolicyKit path
  * CheckPolkitPrivs: clearer error message for files in /etc/polkit-default-privs.d
* Thu Feb 14 2019 jsegitz@suse.com
- Whitelisted pam_p11 (bsc#1123916)
* Sat Feb  2 2019 Dirk Mueller <dmueller@suse.com>
- add 0001-ZipCheck-Also-ignore-RuntimeError.patch (bscs#1124054)
* Fri Feb  1 2019 Axel Braun <axel.braun@gmx.de>
- added user/group tryton (GNU Health)
* Mon Jan 14 2019 Dirk Mueller <dmueller@suse.com>
- disable UseVersionInChangelog by default
* Sat Jan 12 2019 Dirk Mueller <dmueller@suse.com>
- update to 1.11:
  * Avoid exception on inaccessible scripts
  * Print out the error content on UnicodeError to make flake8 happy
  * Fix flake8 warning about missing space around operators
  * Use compressions when checking for backup files
  * Account for arch specific code in /usr/share
  * Check for installed libtool wrapper files
  * Check for missing optional dependencies
  * Consider gnome help for doc files
  * Check for noarch package with files in lib64
  * Verify if description is longer than summary
  * Explicitly tell users how to set URL
  * Ignore pytest_cache directory
  * confusing-invalid-spec-name
  * Ignore orig/rej leftovers after patching
  * Reenable Travis testing against Fedora Rawhide
  * Check all sections that should not use %%buildroot in them
  * Put in default buildroot value used by Fedora/openSUSE
  * Stricter interpreter check
  * Use compileall to avoid %%buildroot to be in pyc
  * Drop deprecated config file usage, 0.88 is pretty old anyway
  * Adjust Version to not print outdated Copyright
  * Rework Travis checks against latest Centos and Fedora releases
  * Fix exception handling
  * Fix various flake8-import-order test regressions
  * Blacklist newer pycodestyle warnings
  * Fix compatibility with file 5.33+
  * Python 3.7.0b5 magic number is 3394
  * Update TagsCheck.py
  * pyc related tests: DRY
  * Fix getting pyc mtime on Python 3.7
  * Always import XDG desktop files as utf8
  * Fix Flake8 warnings
  * Update Magic values for Python 3.7 (Fixes #123)
  * Improve XDG Menu checks stability
  * Test added.
  * Ignore useless-provides on debuginfo provides (#112)
  * Properly handle the exception on missing files
  * Avoid calling close on undefined fd variable
  * Code formatting fixed to meet the style.
  * Modify FakePkg to let the test.sh pass.
  * _sourcedir macro defined.
  * Avoid summary-not-capitalized warning on digits
  * Avoid catch-all except statements
  * Use ImportError to avoid catch-all except: statements
  * Handle E741: ambiguous identifier
  * Accept python(abi) as a valid versioned python dependency
  * Binariescheck: Check for chroot/chdir on ARM, PPC
  * Avoid false positives on is_elf check
  * Handle %%post scripts that contain non-ascii characters
  * Further tweak lib_regex
  * split wrong-script-interpreter into env-script-interpreter
  * Validate Appdata also when appstream-util is unavailable
  * Remove dependency on unicodedata
  * Lower false-positives on summary-not-capitalized
  * Tighten wrong-script-interpreter check to lower false positives
  * Check for unexpanded macros in more Tags
  * Rename local file variable to fname
  * Skip binaryinfo-readelf-failed on non-ELF archives
  * Add check for validating file extensions
  * Do not report error if call positions are unknown
  * Execute chroot tests also on x86 rpms
  * Tighten lib_regex to avoid false positive in python bindings
  * Better details for wrong-script-interpreter
  * Extend scm_regex to capture more SCM system files
  * AppDataCheck: Pass --nonet to appstream-util if NetworkEnabled is False
  * test: Fix cpio location in centos6
  * test: Combine run commands in fedoradev container
  * test: Remove dnf upgrade from fedora containers
  * test: Dockerfile whitespace tweaks
- drop patches that were upstreamed:
  0001-Accept-python-abi-as-a-valid-versioned-python-depend.patch,
  0001-Always-import-XDG-desktop-files-as-utf8.patch,
  0001-Avoid-calling-close-on-undefined-fd-variable.patch,
  0001-Avoid-false-positives-on-is_elf-check.patch,
  0001-Backport-d8f423b575e8be387d33bc3af176baf978efacbb.patch,
  0001-Binariescheck-Check-for-chroot-chdir-on-ARM-PPC.patch,
  0001-Execute-chroot-tests-also-on-x86-rpms.patch,
  0001-Extend-scm_regex-to-capture-more-SCM-system-files.patch,
  0001-Fix-compatibility-with-file-5.33.patch,
  0001-Handle-post-scripts-that-contain-non-ascii-character.patch,
  0001-Improve-XDG-Menu-checks-stability.patch,
  0001-Tighten-wrong-script-interpreter-check-to-lower-fals.patch,
  0001-split-wrong-script-interpreter-into-env-script-inter.patch,
  0003-Tighten-lib_regex-to-avoid-false-positive-in-python-.patch,
  0007-Validate-Appdata-also-when-appstream-util-is-unavail.patch,
  better-wrong-script.diff, buildroot-doc.diff,
  buildroot-in-scripts.diff, compressed-backup-regex.diff,
  confusing-invalid-spec-name.diff, description-check.diff,
  drop-unicodedata-dep.diff, ignore-readelf-ar-error.diff,
  libtool-wrapper-check.diff, noarch-lib64.diff,
  omit_BUILDROOT_from_pyo_files.patch,
  selfconflicts-provide.diff, stricter-interpreter-check.diff,
  suse-whitelist-opensuse.diff, update-magic-values-python-37.patch,
  usr-arch.diff
* Wed Jan  9 2019 opensuse-packaging@opensuse.org
- Update to version master:
  * Flake8 fix
* Wed Jan  9 2019 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master (bsc#1116686):
  * Ignore decoding errors as we're not sure we know the encoding
  * Use UTF-8 encoding when opening .pc file (#42)
  * whitelist otrs permission file (#41)
  * Relax various flake8 warnings
  * Handle '-n' option for %%service_del_preun %%service_del_postun
  * There isn't a good standard, whether the directory should be called 'tests/' or 'test/'
* Wed Jan  2 2019 Martin Liška <mliska@suse.cz>
- Add 0001-Backport-d8f423b575e8be387d33bc3af176baf978efacbb.patch
* Fri Dec 21 2018 matthias.gerstner@suse.com
- whitelist boltd dbus service (bsc#1119975)
* Wed Dec 12 2018 mardnh@gmx.de
- Add user/group 'bird' for package bird (network/bird)
* Fri Dec  7 2018 Todd R <toddrme2178@gmail.com>
- Add xrootd gid and uid whitelist.
  This is needed by the latest versions of xrootd.
* Mon Dec  3 2018 matthias.gerstner@suse.com
- whitelist pam_slurm_adopt (bsc#1116758)
* Tue Nov 20 2018 eich@suse.com
- Add group 'singularity', remove user 'singularity' which was
  added mistakenly.
* Tue Nov 20 2018 eich@suse.com
- Add user/group 'slurm' for package slurm
  (See network:cluster/slurm) (FATE#316379).
* Fri Nov 16 2018 Antonio Larrosa <alarrosa@suse.com>
- Add mpd user
* Fri Nov 16 2018 Dirk Mueller <dmueller@suse.com>
- update libtool-wrapper-check.diff to handle inaccessible files
* Thu Nov  8 2018 jsegitz@suse.com
- whitelist keepalived dbus service (bsc#1015141)
* Tue Oct 23 2018 matthias.gerstner@suse.com
- remove openswan whitelisting (deleted from Factory, replaced by libreswan,
  boo#1089340)
* Wed Oct 17 2018 jsegitz@suse.com
- whitelist systemd-timesyncd (bsc#1111254)
* Tue Oct 16 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * Use only one pattern that covers both cases
  * Add support to identify tmpfiles_create used with just a basename
* Mon Oct  8 2018 opensuse-packaging@opensuse.org
- Update to version master:
  * security checks: add link to openSUSE wiki to error message details
* Fri Oct  5 2018 matthias.gerstner@suse.com
- whitelist NetworkManager-fortisslvpn (bsc#1109938)
* Mon Sep 24 2018 matthias.gerstner@suse.com
- whitelist iwd D-Bus service (bsc#1108037)
* Wed Sep 12 2018 mpost@suse.com
- Add new zkeyadm group
* Mon Sep  3 2018 Markos Chandras <mchandras@suse.de>
- Add new firejail group
* Mon Aug 20 2018 matthias.gerstner@suse.com
- whitelist xpra D-Bus service (bsc#1102836)
* Wed Aug  8 2018 lnussel@suse.de
- adjust maximum valid suse_version to 1550 (boo#1104110)
* Fri Jul 20 2018 matthias.gerstner@suse.com
- whitelist ratbagd D-Bus service (bsc#1076467)
* Thu Jul 12 2018 dmueller@suse.com
- remove unnecessary suse-check-optional-dependencies.diff
- drop CheckBuildDate - does not produce hits and is
  relatively slow
* Wed Jul 11 2018 dmueller@suse.com
- add suse-rpmlint-all-pie.patch: refresh to handle the pie-executable
  case (rename from rpmlint-all-pie.patch)
* Mon Jul  9 2018 dmueller@suse.com
- drop obsolete suse-no-run-ldconfig.diff,
  suse-manpages-for-rc-scripts.diff
* Thu Jul  5 2018 matthias.gerstner@suse.com
- whitelist pam_oath PAM module after audit (bsc#1089114)
* Tue Jul  3 2018 mcepl@suse.com
- Add update-magic-values-python-37.patch
    Neccessary for update of Python to 3.7
    https://github.com/rpm-software-management/rpmlint/commit/52b715763217
* Tue Jul  3 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * New file 5.33 does identify pie executables now (bsc#1097339)
- add 0001-Fix-compatibility-with-file-5.33.patch
* Mon Jul  2 2018 c.schweingruber@catatec.ch
- Add 'sogo' user and group (used in server:SOGo)
* Mon Jun 11 2018 matthias.gerstner@suse.com
- whitelisting NetworkManager-libreswan plugin (bnc#1089340)
* Mon Jun  4 2018 dmueller@suse.com
- add Lua/NodeJS related groups to list of valid groups (bsc#1095769)
* Mon Jun  4 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * Blacklist python test folder in python packages
  * Error out on /etc/bash_completion.d in packages
  * Do not use otherproviders() SUSEism
* Wed May 16 2018 andy@onthewings.net
- Add Development/Languages/OCaml group.
* Fri May  4 2018 okurz@suse.com
- Add 'synapse' user and group.
* Wed May  2 2018 mchandras@suse.de
- Add 'openvswitch' user and group.
* Thu Apr 19 2018 matthias.gerstner@suse.com
- whitelisting pam_yubico module (bsc#1087060)
* Tue Apr 10 2018 matthias.gerstner@suse.com
- adding new names for kalarm DBUS service (bsc#1087714)
* Sun Apr  1 2018 novell@chromanet.de
- added bacula user and group.
* Thu Mar 22 2018 sleep_walker@opensuse.org
- Add tox user and toxcmd group as standard openSUSE GID and UID
* Fri Mar  9 2018 matthias.gerstner@suse.com
- Corrected tpm2-abrmd (bnc#1049694). The D-Bus activation file is named
  differently than the configuration file.
* Tue Feb 20 2018 dimstar@opensuse.org
- Add one more deprecated license:
  + GPL-2.0-with-font-exception.
* Tue Feb 20 2018 coolo@suse.com
- allow more deprecated licenses to unbreak ring1+2
* Sun Feb 18 2018 dmueller@suse.com
- add 0001-Always-import-XDG-desktop-files-as-utf8.patch
* Thu Feb 15 2018 coolo@suse.com
- Allow some deprecated licenses that we would replace on commit
  (SPDX 2->SPDX 3 conversion)
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * polkit: make untracked privileges also an error
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Update rpmlint-checks to version master:
  * Support uppercase tag macros used by RPM 4.14
* Thu Feb  8 2018 opensuse-packaging@opensuse.org
- Update to version 84.87+git20180202.3df4ae7:
  * Add testcases for MenuXDGCheck.py
* Tue Jan 23 2018 dmueller@suse.com
- refresh for 0001-Improve-XDG-Menu-checks-stability.patch
  remove xdg-paths-update.diff (merged into other patch)
* Mon Jan 15 2018 krahmer@suse.com
- whitelisting usbauth (bsc#1066877)
* Sun Jan 14 2018 ngompa13@gmail.com
- Add Development/{Languages,Libraries}/Rust groups as noted in wiki
* Wed Jan  3 2018 adam.majer@suse.de
- add missing comma (,) to config file
- add user/group _nsd for NSD name server
* Sat Dec  2 2017 stefan.bruens@rwth-aachen.de
- add 0001-Binariescheck-Check-for-chroot-chdir-on-ARM-PPC.patch
* Wed Nov 29 2017 krahmer@suse.com
- whitelisting kcmsddm (bsc#1065563)
* Fri Nov 24 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Fix warnings
  * Add new rpmlint check for new %%{_fillupdir} macro (boo#1069468)
  * Open paths within the rpm file itself
  * Fix python warning
  * BashismCheck: Only check regular files
  * Rewrite BashismsCheck to actually work
* Tue Nov 14 2017 dimstar@opensuse.org
- Add rpmlint-slpp-NUM-NUM.patch: Match libFOO<num>-<num> as a
  valid dependency on a libary. According the openSUSE packaging
  policy, if the library name ends on a number, we add a dash
  between the basename (before the .so) and the version after .so.
* Fri Nov  3 2017 opensuse-packaging@opensuse.org
- Update rpmlint-tests to version master:
  * Add Flake8 travis check
  * Fix scriptprog invocation
  * Print the duplicated filenames sorted to be stable accross multiple calls
* Wed Nov  1 2017 dmueller@suse.com
- add 0001-Avoid-calling-close-on-undefined-fd-variable.patch
* Tue Oct 24 2017 jengelh@inai.de
- Description updates. Use the %%make_install macro.
* Tue Oct 24 2017 dmueller@suse.com
- update suse-whitelist-opensuse.diff to avoid a false positive
* Tue Oct 24 2017 krahmer@suse.com
- adding connman (bsc#1057697)
* Sat Oct 21 2017 dmueller@suse.com
- add 0001-Accept-python-abi-as-a-valid-versioned-python-depend.patch
* Mon Oct 16 2017 dmueller@suse.com
- refresh 0001-Improve-XDG-Menu-checks-stability.patch (bsc#1063371)
* Wed Oct 11 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Python 3.x porting of the ErlangCheck
* Wed Oct 11 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Treat strongly versioned libs also as compliant (bsc#723726)
  * LibraryPolicy: allow %%%%_licensedir in packages (used by %%license)
- Hide the noisy warnings
* Tue Oct 10 2017 dmueller@suse.com
- add 0001-Avoid-false-positives-on-is_elf-check.patch (bsc#1057216)
  add 0007-Validate-Appdata-also-when-appstream-util-is-unavail.patch
- Update rpmlint-checks to version master:
  * Fix false positives for -theme- -> -branding- rename
  * Stop leaking filedescriptors
  * Pythonic fixes
  * Drop CheckAppdata (there is AppDataCheck upstream)
  * Tighten ELF check
  * Tiny code formatting cleanup
  * Tighten the branding policy reporting a bit to make it less confusing
* Fri Oct  6 2017 lnussel@suse.de
- add package groups from
  https://en.opensuse.org/openSUSE:Package_group_guidelines to enable the
  groups check
* Fri Sep 29 2017 dmueller@suse.com
- Update rpmlint-checks:
  * Flake8 fixes
  * Properly anchor systemd path checks
  * Python 3.x porting
  * Add TmpFilesCheck
  * Flake8 / Stop leaking filedescriptors
  * Port LibraryPolicyCheck to Python 3.x
- Update rpmlint-tests:
  * Stop leaking filedescriptors
  * Address various deprecation warnings
  * Avoid leaking fds and further Python 3.x porting
* Thu Sep 28 2017 dmueller@suse.com
- update to 1.10:
  * test: Skip fedoradev GPG checks at least for now
  * test: Refresh fedora* packages on image build
  * test: Use assertEqual where appropriate, thanks to flake8/hacking
  * test: Update fedora24 config to fedora26, run it on Travis
  * Add a new test for tmpfiles.d snippets in the /etc/ tree.
  * Add new tests for systemd units and udev rules in /etc/ tree
  * test: Disable hacking for now until it's flake8 3.4+ compatible
  * test: Set up flake8-bugbear, enable it in fedoradev container
  * rpmlint: Avoid unused loop control variable
  * ZipCheck: Add TODO
  * *: Avoid mutable argument defaults
  * Be aware of -debugsource packages
  * rpmdiff: Fix unused variable from previous commit
  * rpmdiff: Support soft dependencies
  * BinariesCheck, FilesCheck: Ignore various .build-id dirs
  * Add python3-devel and rpm-build to fedoradev container to provoke some issues
  * BinariesCheck: Popen env consistency fix
  * Pkg.getstatusoutput: Set LC_ALL for all Popens, defaulting to C
  * rpmlint: Fix checking specfile from stdin
  * test.sh: Extract rpmlint command to run_rpmlint
  * Revert "Remove unused spec_lines check_spec argument"
  * BinariesCheck: Trivial cleanups
  * travis: Run make install too
  * FilesCheck: Allow multiple bytecode magic values per Python version
  * tests: Make output test tools easier to reuse
  * FilesCheck: hg.python.org -> github.com/python
  * Pkg: Return vendor and distribution as unicode strings
  * FilesCheck: Add Python 3.7 bytecode magic value
  * Pkg.b2s: Add some more test cases
  * Pkg.b2s: Pass through str as-is on Python 3
  * TagsCheck.py: accept SPDX "and" and "or" operators in all-uppercase spelling
  * rb'foo' is not supported in Python 2, use br'foo' instead
  * travis: Enable centos6
  * Avoid Python 3.6 invalid esc seq warnings, use more raw strings
  * flake8 fixes
  * SpecCheck: Detect patches applied with "patch <" and "patch -i"
  * add /usr/lib/systemd to DEFAULT_HARDCODED_LIB_PATH_EXCEPTIONS (#93)
  * SpecCheck: Do not demand versioned filename Provides/Obsoletes
  * FilesCheck: Update Python 3.6 bytecode magic value again
  * Config: Fix flake8 3.2 / pycodestyle 2.2 errors (closes #82)
  * *: Fix various low hanging issues flagged by pycodestyle 2.1.0 (#82)
  * test.sh: Output flake8 --version
  * rpmdiff.1: update Arturo Borrero Gonzalez email address
  * FilesCheck: Update Python 3.6 bytecode magic value
  * Skip chroot-without-chdir check on non-x86_64
  * shlib-with-non-pic-code: add text on how to figure files compiled without -fPIC (#79)
  * *: Move indentation etc settings to .editorconfig
  * AbstractCheck: Close urllib responses explicitly also on error
  * tests: Switch Travis tests to Docker
  * Use importlib to load checks where available
  * FilesCheck: Use os.devnull
  * Testing: Avoid ResourceWarning on config read
  * Run tests with warnings on
  * Ignore negative returncode after SIGPIPE caused by closing on purpose
  * Fix last commit
  * Use default bufsize, move regex compile to common place
  * BinariesCheck: lower memory requirements, fix chroot/chdir detection
  * FilesCheck: Avoid crash accessing non-ASCII filenames in some cases
  * Filter: More non-ASCII print fixing, including in e.g. C locale
  * SpecCheck: Output spec basename, not tempfile when checking srpm
  * Cleanups
  * FilesCheck: Update Python 3.5 and 3.6 bytecode magic values
  * test: Test for unexpected errors in default and C locales
  * Remove obsolete LC_ALL setting from Makefile
- drop version-control-internal-file.diff, boo1027577-license_tag.patch,
    add-weak-dependencies.diff: upstream
- drop sourced-dirs.diff, fix-shared-library-matching.diff,
    suse-python-abi-check.diff, add-check-for-tmpfiles-created-at-r.diff: obsolete
- drop suse-readd_terminator_in_regex.patch: merged into original patch
- add suse-tests-without-badness.patch,
    0001-Extend-scm_regex-to-capture-more-SCM-system-files.patch,
    0003-Tighten-lib_regex-to-avoid-false-positive-in-python-.patch,
    0001-Execute-chroot-tests-also-on-x86-rpms.patch,
    ignore-readelf-ar-error.diff, remove-ghostfile-checks.diff,
    fix-diag-sortorder.diff, drop-unicodedata-dep.diff,
    0001-Tighten-wrong-script-interpreter-check-to-lower-fals.patch,
    0001-Improve-XDG-Menu-checks-stability.patch,
    0001-split-wrong-script-interpreter-into-env-script-inter.patch,
    0001-Handle-post-scripts-that-contain-non-ascii-character.patch
- drop config.in: unused
- switch to python 3.x
* Thu Sep 28 2017 dmueller@suse.com
- update to 1.9:
  * Pkg: Fix magic.descriptor availability check
  * warn: Define only once, with print_function
  * FilesCheck: Check for *.gir in devel, *.typelib in non-devel, fixes #74
  * FilesCheck: Improve devel-file-in-non-devel-package description
  * flake8: Ignore H105
  * Makefile: Remove generate-isocodes dep from __isocodes__
  * __isocodes__: Regenerate
  * generate-isocodes: Switch to JSON source files (#72)
  * test.sh: Check man pages for warnings
  * Delete dead if-block
  * Filter: Line wrap cleanup
  * Filter: Use sys.version_info to check Python version
  * Fix octal string literals
  * Solve exceptions on printing str (Fixes #61)
  * tests: Add autofs binary rpm for testing non-ASCII output issues
  * test: Add some test packages containing non-UTF-8 filenames
  * BinariesCheck: avoid false chroot w/o chdir when objdump fails
  * flake8 fixes
  * rpmdiff: Import site only if needed
  * Testing: Add and use default for path to tests
  * FilesCheck: Update Python 3.6 bytecode magic value
  * FilesCheck: Fix regression in finding shebangs without arguments
  * Ignore .cache dir
  * Clean up Python < 2.6 cruft
  * Add hacking flake8 to Travis and ignores
  * flake8 fixes
  * Use new style classes
  * Run flake8 on rpmdiff and rpmlint too
  * Handle more file open/close with "with"
  * Exception handling cleanups
  * FilesCheck: Look for shebang only at start of file
  * travis: python3-rpm doesn't exist even for Trusty, so can't test with 3.4
  * travis: Switch to Ubuntu Trusty, test with Python 2.7 and 3.4
  * Use Travis apt addon for whitelisted packages
  * Test import order
  * Sort imports per PEP8, Google Python Style Guide
  * Add Python 3.6 magic value
  * Fix resolving Python source from 3.5 *.opt-[12].pyc
  * Move most Emacs settings to .dir-locals.el
  * Add %%python2_sitearch and %%python3_sitearch to private SO paths
  * Prevent empty paths from entering private SO paths
  * remove files-attr-not-set check
  * Expand postin/postun once per pkg instead once per file
  * Install rpm in travis for signature check
  * Avoid running some regexps
  * Run flake8 in test suite
  * flake8 fixes
  * make test suite fail on more errors
  * Comment update
  * Note and test libmagic >= 5.05 dep
  * Fix magic processing for Python 3
  * Mimic magic closer for symbolic links
  * Workaround slowness due to python-magic bug
  * Shortcut file magic, derive from file mode
  * Spelling fix
  * Unbreak create_*regex_call now that lines are shortened by call_regex
  * Drop unnecessary symbol_table_regex
  * Avoid false function call vs definition positives, thanks to Stefan Bruens
  * pep8 fixes
  * Add some pep8 settings
  * Split parsing of readelf output into header and symbols part
  * Skip checks for problematic function calls if common prefix does not match
  * Use shlex.quote for better shell escaping where available
  * TODO update
  * Don't limit build badge to master branch
  * Convert README to markdown
  * Travis: install rpm2cpio
  * +TODO
  * Travis: Use Python 2.7 and system site packages
  * Travis: try pytest from pip instead of apt-get
  * Initial travis setup
  * Include interpreter arguments in output messages for filtering control
  * Flag /usr/bin/env as a wrong interpreter
- drop rpmlint-pkg-quoting.diff, suse-g-ir-chech.diff, remove-expand-macros.diff,
  remove-files-attr-not-set-check.diff, postin-speedup.diff, binaryinfo-speedup.diff,
  0001-Fix-resolving-Python-source-from-3.5-.opt-12.pyc.patch,
  issue_68_BinariesCheck_lower_memory-1.patch, issue_68_BinariesCheck_lower_memory-2.patch,
  issue_68_BinariesCheck_lower_memory-3.patch, issue_68_BinariesCheck_lower_memory-4.patch,
  BinariesCheck_fix_chroot_check_on_non_x86.patch: either upstreamed as is or slightly different
- drop suse-sysv-init-checks.diff, 0001-Avoid-messing-with-the-error-encoding-Fixes-61.patch,
  suse-filesystem.diff, script-interpreter-only-for-exec-sc.diff: obsolete
- drop update_git.sh related stuff: this is obsolete, patches are
  either supposed to be upstreamed or handled via quilt
- add suse-skip-macro-expansion.diff: rename from remove-expand-macros.diff
* Thu Sep 28 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * Ignore trailing whitespace in permission files (bsc#1060738)
* Fri Sep 22 2017 eich@suse.com
- Add group 'singularity' for package singularity
  (See network:cluster/singularity) (FATE#323048).
* Wed Sep 20 2017 daniel.molkentin@suse.com
- Add dehydrated user & group for dehydrated, a letsencrypt client
  FATE#323377
* Wed Sep  6 2017 krahmer@suse.com
- Adding fwupd (bsc#932807)
* Tue Aug 15 2017 bliu@suse.com
-  add coroqnetd for corosync-qnetd to rpmlint
* Mon Aug 14 2017 matthias.gerstner@suse.com
- Adding NetworkManager-l2tp (bsc#846337)
* Mon Aug 14 2017 matthias.gerstner@suse.com
- Adding pam_script (bsc#1039848)
* Tue Aug  8 2017 krahmer@suse.com
- Adding nfs-ganesha (bsc#997880)
* Tue Jul 25 2017 matthias.gerstner@suse.com
- Added tpm2-abrmd (bnc#1049694)
* Sat Jul 15 2017 ilya@ilya.pp.ua
- Add user mednafen for mednafen network play server
* Tue Jul 11 2017 krahmer@suse.com
- Adding pam_dbus (bsc#1039709)
* Thu Jun 22 2017 meissner@suse.com
- rpmlint-all-pie.patch: for non-PIE built binaries emit a warning
  to suggest build them as PIE.
* Tue Jun  6 2017 marec@detebe.org
- std-user and std-group 'bitcoin' added for building correct bitcoin daemon
* Thu Jun  1 2017 stefan.bruens@rwth-aachen.de
- Add BinariesCheck_fix_chroot_check_on_non_x86.patch
  Check for correct invocation of chroot was only implemented for x86
* Wed May 31 2017 jochen.becker@hrz.tu-darmstadt.de
- std-user and std-group 'xymon', added for building correct xymon client
* Wed May 31 2017 krahmer@suse.com
- whitelisting openqa (bsc#1039290)
* Thu May 25 2017 tserong@suse.com
- add 'prometheus' and 'grafana' standard users and groups
* Tue May 16 2017 krahmer@suse.com
- whitelisting switchroo-control (bsc#1034309)
* Fri Apr 28 2017 mgerstner@suse.com
- whitelisting backintime (bsc#1007723, bsc#1032717)
* Wed Apr 19 2017 krahmer@suse.com
- whitelisting thunderbolt (bsc#1033554)
* Tue Apr 18 2017 opensuse-packaging@opensuse.org
- Update to version master:
  * remote unused/outdated checks
* Tue Apr 18 2017 opensuse-packaging@opensuse.org
- Update to version 84.87+git20170418.092177d:
  * Remove initscript related tests, systemd FTW!
* Tue Apr 11 2017 mgerstner@suse.com
- Adding kwalletmanager5 (bsc#1033296)
* Tue Apr 11 2017 krahmer@suse.com
- Adding os-autoinst (bsc#1032649)
* Mon Apr 10 2017 dmueller@suse.com
- remove CheckKDE4Deps, CheckInitScripts
* Mon Mar 20 2017 lnussel@suse.de
- actually enable CheckSysVinitOnSystemd
* Fri Mar 17 2017 kkaempf@suse.com
- Add logstash to StandardGroups and StandardUsers.
* Thu Mar  9 2017 lnussel@suse.de
- rpmlint-checks:
  * Check for old SysVinit scripts and the usage of insserv (FATE#322953)
  * Prevent a false-positive in systemd
* Thu Mar  2 2017 mimi.vx@gmail.com
- fix boo#1027577
  patch boo1027577-license_tag.patch
* Mon Feb  6 2017 lars@linux-schulserver.de
- rename user/group sks to _sks following
  https://github.com/LinuxStandardBase/lsb/pull/21
* Mon Feb  6 2017 krahmer@suse.com
- adding blueman (bsc#987141)
* Tue Jan 31 2017 zaitor@opensuse.org
- Add gdm to StandardGroups.
- Add polkitd to StandardUsers.
* Tue Jan 31 2017 meissner@suse.com
- suse-spdx-license-exceptions.patch: removed fuzziness from patch.
- issue_68_BinariesCheck_lower_memory.patch: split into seperate patches
  issue_68_BinariesCheck_lower_memory-1.patch
  issue_68_BinariesCheck_lower_memory-2.patch
  issue_68_BinariesCheck_lower_memory-3.patch
  issue_68_BinariesCheck_lower_memory-4.patch
  and unfuzzed patch number 3.
* Tue Jan 31 2017 krahmer@suse.com
- Whitelisting rebootmgr (bsc#1019644)
* Tue Jan 24 2017 krahmer@suse.com
- Whitelisting powerdevil discretegpuhelper (bsc#1019748)
* Mon Jan  9 2017 krahmer@suse.com
- Adding org.freedesktop.resolve1.conf (bsc#917781)
* Tue Jan  3 2017 stefan.bruens@rwth-aachen.de
- add suse-readd_terminator_in_regex.patch
  Fixes bad detection of dependencies for devel packages
* Mon Jan  2 2017 dmueller@suse.com
- update suse-obsolete-version check (bsc#743981)
* Mon Dec  5 2016 krahmer@suse.com
- whitelisting pam_slurm (bsc#1007053)
* Wed Oct 26 2016 krahmer@suse.com
- whitelisting pam_gdm (bsc#1004346)
* Tue Oct 11 2016 meissner@suse.com
- config: whitelist flatpak dbus service/config (bsc#984817)
* Wed Sep 14 2016 krahmer@suse.com
- adding sysprof DBUS service (bsc#996111)
* Tue Sep  6 2016 lars@linux-schulserver.de
- Adding sks (Synchronizing Key Server) to known user/group
* Tue Sep  6 2016 lnussel@suse.de
- rpmlint-checks:
  * Make checks python3 compatible
  * Fix update-alternatives check when it's quoted
* Fri Aug 19 2016 stefan.bruens@rwth-aachen.de
- Update some checks to work on both Python 2 and 3
* Mon Jul 25 2016 lnussel@suse.de
- rpmlint-checks:
  * Fix typo in BrandingPolicyCheck.py
* Thu Jun 30 2016 stefan.bruens@rwth-aachen.de
- Add issue_68_BinariesCheck_lower_memory.patch
  Fixes out-of-memory errors on 32bit systems (bsc#969732)
* Fri Jun 17 2016 mvetter@suse.com
- Adding prosody to known user/group
* Fri May 27 2016 alarrosa@suse.com
- add 0001-Fix-resolving-Python-source-from-3.5-.opt-12.pyc.patch:
  Fixes FilesCheck to resolve correctly the python source file
  from pyc files following PEP0488 (like *.{tag}.opt-[12].pyc).
  (bsc#982076)
* Thu May 19 2016 dmueller@suse.com
- suse-spdx-license-exceptions.patch, suse-sysv-init-checks.diff:
  adjust to match rpmlint-tests again
* Thu May 19 2016 dmueller@suse.com
- update link to list of valid licenses
* Thu May 19 2016 meissner@suse.com
- temporary approval for tcmu-runner dbus service (bsc#978903)
* Tue May  3 2016 stefan.bruens@rwth-aachen.de
- add omit_BUILDROOT_from_pyo_files.patch (boo#978306)
* Wed Apr  6 2016 dmueller@suse.com
- add suse-spdx-license-exceptions.patch (bsc#973404)
* Wed Mar 30 2016 krahmer@suse.com
- whitelisting openattic (bsc#972478)
* Thu Mar 24 2016 mpost@suse.com
- Updated config file to add user chrony and group chrony
  (Fate#319508)
* Mon Mar 14 2016 christoph@stop.pe
- whitelist rabbitmq user and group
* Tue Mar  8 2016 stefan.bruens@rwth-aachen.de
- Fix boo#970170: rpmlint no longer detects gethostbyname calls,
  also detect gethostbyname{,2}{,_r}, gethostbyaddr{,_r}
  * update suse-binariescheck.diff
  * rpmlint-check-gethostbyname.patch
* Mon Feb 22 2016 dmueller@suse.com
- add 0001-Avoid-messing-with-the-error-encoding-Fixes-61.patch (bsc#967556)
- fix requires
* Fri Feb 12 2016 sleep_walker@opensuse.org
- add 'guixbuild' as standard group
- don't require %%config for bash completion scripts in /etc
* Thu Feb  4 2016 lnussel@suse.de
- whitelist systemd-importd (bnc#964935)
* Thu Jan 28 2016 dmueller@suse.com
- enable tests during building
* Thu Jan 21 2016 dmueller@suse.com
- add postin-speedup.diff, binaryinfo-speedup.diff
* Wed Jan 20 2016 krahmer@suse.com
- whitelist iio-sensor-proxy (bsc#939191)
* Wed Jan 13 2016 krahmer@suse.com
- whitelist drbdmanage DBUS (bsc#956811)
* Fri Dec 11 2015 astieger@suse.com
- add wireshark group [bsc#957624]
* Tue Dec  1 2015 krahmer@suse.com
- adding thermald DBUS service (bsc#954771)
* Mon Nov 30 2015 lnussel@suse.de
- fix shared library matching (fix-shared-library-matching.diff)
* Fri Nov 13 2015 lnussel@suse.de
- rpmlint 1.8 update
  * python 3 fixes
  * Add support for file triggers
  * Mechanism to black list certain C calls
  * new error: non-devel-file-in-devel-package
  * appdata check configurable
  * project moved to github
  * Patches dropped:
  avoid-mismatched-libregex.diff
  filename-non-utf8-exception.diff
  fix-ghost-file-handling.diff
  save-content-to-an-array.diff
  fix-TmpFilesCheck-pattern-match.diff
  move-ghost-file-check-to-TmpFilesCh.diff
* Fri Nov 13 2015 lnussel@suse.de
- fix TmpFilesCheck not finding pattern in the full script
  (fix-TmpFilesCheck-pattern-match.diff)
* Mon Nov  9 2015 krahmer@suse.com
- whitelisting cinnamon settings daemon (bsc#951830)
* Wed Oct 14 2015 lnussel@suse.de
- Speedup CheckBuildDate check
- add _service file snippet for rpmlint-checks and regenerate from git
* Fri Sep 11 2015 aboe76@gmail.com
- Added salt user and group (bnc#939831)
* Wed Sep  9 2015 krahmer@suse.com
- Added teamd DBUS config (bnc#941993)
* Tue Sep  8 2015 kstreitova@suse.com
- Add shibd user and group [fate#318304]
* Thu Jul  9 2015 msrb@suse.com
- Add vnc user and group. (fate#318936)
* Tue Jun 30 2015 meissner@suse.com
- add a whitespace line as %%autosetup seems broken.
* Wed Jun 24 2015 tchvatal@suse.com
- Add mysql group to the known groups
* Wed May 20 2015 lnussel@suse.de
- skip files handled by tmpfile mechnism in regular ghost file check
  (move-ghost-file-check-to-TmpFilesCh.diff)
* Tue May 19 2015 lnussel@suse.de
- fix update_git.sh
- make sure tmpfiles are listed in %%files
  (add-check-for-tmpfiles-created-at-r.diff)
- don't complain about missingok ghost files
  (fix-ghost-file-handling.diff)
- remove obsolete check for %%defattr in spec files
  (remove-files-attr-not-set-check.diff)
* Fri Apr 24 2015 tserong@suse.com
- added standard user and group ceph (bnc#928492)
* Wed Apr 22 2015 krahmer@suse.com
- fixing some .conf/.service suffixes
* Wed Apr 22 2015 krahmer@suse.com
- adding realmd DBUS service (bnc#916766)
* Mon Apr 20 2015 lnussel@suse.de
- update save-content-to-an-array.diff with upstream version
* Fri Apr 10 2015 lnussel@suse.de
- new versioin 1.6
- add script update_git.sh based on qemu's to simplify importing
  a patch series from git after rebasing.
  * Patches dropped:
  0001-Python-3-compatibility-tweaks.patch (upstream)
  0001-Set-Python-3.4-magic-number-to-3310.patch (upstream)
  add-scoring-support.diff (different upstream solution)
  check-buildroot-during-install.diff (need to fix no-cleaning-of-buildroot check upstream)
  fix-versioned-prereq.diff (was disabled, not sure what it's useful for)
  ignore-non-readable-in-etc.diff (filtered anyways)
  locale-support.diff (drop)
  locale-update.diff (different upstream solution now)
  more-verbose-lsb-check.diff (drop)
  perl-versioned-rpath-deps.diff (upstream)
  rpmlint-1.5-disallow-var-run-and-var-lock.diff (upstream)
  rpmlint-1.5-Fix-setgroups-error-name.diff (upstream)
  rpmlint-decode-fix.diff (different upstream solution)
  rpmlint-fix-unexpanded-macros-for-array-values.patch (different upstream solution)
  stricter-tags-check.diff (merged in weak deps and check-for-self-provides.diff)
  suppress-for-perl-python.diff (use filter instead)
  suse-binary-info-compile-opts.diff (drop)
  suse-changelog.patch (change config instead)
  suse-mono-deps-checks.diff (useful?)
  suse-required-lsb-tags.diff (different upstream solution)
  verify-buildrequires.diff (very build system specific, drop)
  xdg-check-exception.diff (upstream)
  * renamed patches:
  script-interpreter-only-for-exec-scripts.diff
  - > script-interpreter-only-for-exec-sc.diff
  confusing-invalid-spec-name.patch
  - > confusing-invalid-spec-name.diff
  suse-manpages-for-rc-scripts.patch
  - > suse-manpages-for-rc-scripts.diff
  sysv5-init-checks.diff
  - > suse-sysv-init-checks.diff
  * added patches:
  check-for-self-provides.diff
  save-content-to-an-array.diff
* Thu Apr  9 2015 meissner@suse.com
- use the correct networkd dbus service names. (bnc#918799)
* Mon Mar  9 2015 krahmer@suse.com
- added systemd network DBUS service (bnc#918799)
* Wed Feb 11 2015 krahmer@suse.com
- added storaged DBUS service (bnc#915769)
* Tue Feb 10 2015 kkaempf@suse.com
- add standard users and groups pcp and pcpqa for pcp
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- whitelist sddm (boo#897788)
* Wed Dec 10 2014 krahmer@suse.com
- added firewalld dbus service (bnc#907625)
* Wed Dec  3 2014 krahmer@suse.com
- added iouyap group (bnc#904060)
* Mon Dec  1 2014 jmatejek@suse.com
- added standard user and group davfs2 (bnc#907662, FATE#318116)
* Mon Oct 27 2014 tboerger@suse.com
- Added standard user and group crowbar for crowbar systemmanagement
* Wed Sep 24 2014 sfalken@opensuse.org
- added standard user and group siproxd for the siproxd proxy
* Wed Aug 27 2014 wagner-thomas@gmx.at
- added standard user iodined for the iodine DNS tunnel daemon
* Fri Aug 22 2014 nwang@suse.com
- FATE#314409. Add libstoragemgmt user/group.
* Thu Aug 21 2014 hrvoje.senjan@gmail.com
- Add sddm user/group
* Thu Aug 21 2014 wagner-thomas@gmx.at
- Added standard user/group polipo
* Thu Aug 21 2014 darin@darins.net
- Add user/group unbound for unbound caching dns server
* Thu Aug 21 2014 lnussel@suse.de
- adjust initscript check to match new systemctl based
  %%restart_on_update resp %%stop_on_removal
* Mon Jul 21 2014 werner@suse.de
- Add the groups systemd-journal, systemd-journal-gateway, and tape
  as required by systemd
- Add the user systemd-journal-gateway as required by systemd
* Fri Jul 18 2014 jsegitz@suse.com
- updated rpmlint-checks-master.tar.gz to include CheckSystemdInstall.py
* Thu Jul 17 2014 meissner@suse.com
- allow org.kde.kf5auth.conf after adjustment of race condition
  (bnc#864716)
* Tue Jul  8 2014 achernikov@suse.com
- added user and group sensu required for sensu server, client
* Tue Jul  1 2014 meissner@suse.com
- allow user and group ddclient for the ddclient users (bnc#881520)
* Fri Jun 20 2014 meissner@suse.com
- allow user bitlbee for the bitlbee irc server.
* Wed Jun 11 2014 krahmer@suse.com
- enable oFono DBUS for SLE12 (bnc#862354)
* Mon May 19 2014 meissner@suse.com
- enable org.selinux.service and org.selinux.conf of policycoreutils
  (pending more review) bnc#878631
* Thu May  8 2014 dmueller@suse.com
- add 0001-Set-Python-3.4-magic-number-to-3310.patch (bnc#876470)
* Tue May  6 2014 lnussel@suse.de
- dd filter expections for filesystem package
* Mon May  5 2014 lnussel@suse.de
- disallow /var/run and /var/lock
  (rpmlint-1.5-disallow-var-run-and-var-lock.diff)
* Fri Apr 25 2014 evilissimo@redhat.com
- adding ovirtagent standard user and standard group names (uid/gid 175)
* Tue Apr 22 2014 krahmer@suse.com
- adding baloo DBUS service file (missing in last request) (bnc#866131)
* Wed Apr 16 2014 krahmer@suse.com
- adding baloo DBUS config, formerly nepomuk (bnc#866131)
* Fri Apr  4 2014 lnussel@suse.de
- allow /run (bnc#870190)
* Wed Apr  2 2014 dmueller@suse.com
- update KMPPolicycheck
* Sat Mar 29 2014 chris@computersalat.de
- added group 'squid' for squid
* Wed Mar 26 2014 chris@computersalat.de
- added user, group 'boinc' for boinc-client
* Tue Mar 18 2014 meissner@suse.com
- allow org.freedesktop.GeoClue2.Agent.conf (bnc#862216)
* Wed Mar  5 2014 lnussel@suse.de
- add minimal check to verify appdata.xml files are parsable XML
* Thu Feb 27 2014 aplanas@suse.com
- added patches:
  * rpmlint-fix-unexpanded-macros-for-array-values.patch
- fix _unexpanded_macros for array values
* Thu Feb 27 2014 lnussel@suse.de
- rip out all decode in an attempt to make it work
- modified patches:
  * rpmlint-decode-fix.diff
* Thu Feb 27 2014 aplanas@suse.com
- added paches:
  * rpmlint-decode-fix.diff
- Fix decode from UTF-8 string in Python 2
* Sun Feb 23 2014 schwab@suse.de
- usr-arch.diff: update usr_arch_share_regex
* Fri Feb 21 2014 mls@suse.de
- adapt to new rpm weak dependency tags
* Fri Feb 21 2014 dmueller@suse.com
- added patches:
  * 0001-Python-3-compatibility-tweaks.patch
- Change openstack- related users to non-prefixed variants,
  as they get renamed with the switch to Icehouse
* Mon Feb 10 2014 krahmer@suse.com
- whitelisting networkmanager-openswan (bnc#808549)
* Thu Jan 30 2014 lnussel@suse.de
- remove suse-rclink-check.diff and implement as separate check for
  systemd units instead (bnc#860340).
* Tue Jan 28 2014 mpost@suse.com
- Added group 'ts-shell' for terminal server
* Wed Nov 27 2013 krahmer@suse.com
- Whitelisting NFC neard DBUS service (bnc#837978)
* Wed Nov 20 2013 f.celler@triagens.de
- Add user and group 'arangodb' for ArangoDB database server
* Wed Nov 20 2013 krahmer@suse.com
- Whitelisting kwallet DBUS service (bnc#849739)
* Tue Nov 19 2013 krahmer@suse.com
- Whitelisting bluez DBUS service (bnc#768062)
* Mon Nov 18 2013 krahmer@suse.com
- Adding org.selinux DBUS service (bnc#848550)
* Wed Oct 23 2013 heinemannj66@gmail.com
- Add 'elasticsearch' to standard users and groups
  * package: elasticsearch
  * Summary: Open Source, Distributed, RESTful Search Engine
  * URL: http://www.elasticsearch.org
  * License: Apache-2.0
  * systemd elasticsearch.service needs
    LimitNOFILE=65535
    LimitMEMLOCK=infinity
    for user and group elasticsearch
* Tue Oct 15 2013 krahmer@suse.com
- Whitelisting com.redhat.tuned DBUS service (bnc#787379)
* Mon Sep 30 2013 dmueller@suse.com
- Sync checks with git (FATE#316521)
* Wed Sep 25 2013 meissner@suse.com
- whitelist second iteration of wicked dbus service names
  (bnc#783932)
* Mon Sep 23 2013 dmueller@suse.com
- blacklist old systemd/udev directories (bnc#816467)
- remove checking for groups (bnc#767551)
- ignore icon size mismatches on animated icons (bnc#480664)
- update obsolete/invalid suse version check
* Tue Sep 17 2013 abergmann@suse.com
- whitelisted mate DBUS Service (bnc#831404)
* Sat Sep 14 2013 matwey.kornilov@gmail.com
- add requirement for ErlangCheck.py (pull request #2)
* Wed Sep 11 2013 abergmann@suse.de
- whitelisted GeoClue2 DBUS Service (bnc#838360)
* Wed Aug 28 2013 meissner@suse.com
- allow pam_mate_keyring (same to gnome keyring) (bnc#831404)
* Fri Aug  9 2013 dmueller@suse.com
- update rpmlint-checks from git
* Wed Aug  7 2013 dmueller@suse.com
- add suse-ignore-specfile-errors.diff:
  ignore specfile-errors
* Tue Aug  6 2013 dmueller@suse.com
- add xdg-check-exception.diff:
  handle xdg menu files without exec entry (bnc#833384)
* Wed Jul 31 2013 meissner@suse.com
- allow pam_snapper after audit (bnc#815383)
* Tue Jul 30 2013 meissner@suse.com
- follow /usr move for the /bin/ binaries in pie.config.
* Tue Jul 30 2013 lnussel@suse.de
- fix setgroups error name, patch from upstream git:
  rpmlint-1.5-Fix-setgroups-error-name.diff
* Mon Jul 29 2013 meissner@suse.com
- allow systemd machined service as-is (bnc#828207)
* Tue Jul 23 2013 meissner@suse.com
- Allow current wicked DBUS services (bnc#783932)
* Thu Jul  4 2013 meissner@suse.com
- allow nepomuk helpers temporary without full audit (bnc#825262)
* Fri Jun 28 2013 dmueller@suse.com
- drop outdated Update-alternatives check (bnc#826993)
- add basic new update-alternatives check
* Fri Jun 21 2013 nkrinner@suse.com
- Add 'chef' to standard users and groups
* Tue Jun 11 2013 meissner@suse.com
- allowed kcm helper for lightdm-kde-greeter (bnc#794705)
* Mon Jun  3 2013 meissner@suse.com
- allow fprintd DBUS services (bnc#792095)
* Thu May 30 2013 tchvatal@suse.com
- Add group 'locate' for mlocate package
* Tue May 28 2013 dmueller@suse.com
- update to 1.5:
  * New Homepage
  * Plenty of new checks
- add compressed-backup-regex.diff
- remove python3_magic_number_fix.diff
* Mon May 20 2013 andreas.stieger@gmx.de
- Add user and group 'svn' for svnserve in package subversion
* Mon Apr 15 2013 meissner@suse.com
- add new ModemManager interface / service (bnc#798273)
* Tue Feb 26 2013 dmueller@suse.com
- add suse-filter-more-verbose.diff:
  * make it more obvious which rpmlintrc causes an exception (bnc#801192)
* Mon Feb 18 2013 meissner@suse.com
- allow nm-iodine-service.conf DBUS service (bnc#781071)
* Fri Feb  8 2013 matwey.kornilov@gmail.com
- Add user and group 'empd' for erlang
* Sat Feb  2 2013 archie@dellroad.org
- Add user 'fonehome' and group 'fonehome'
* Thu Jan 24 2013 aj@ajaissle.de
- Add Kolab users + groups
  * kolab (Kolab System Account / management)
  * kolab-n (Kolab System Account (N) / non-privileged)
  * kolab-r (Kolab System Account (R) / restricted)
* Wed Jan  2 2013 dmueller@suse.com
- fix incorrect branding require warnings
* Thu Dec 20 2012 lnussel@suse.de
- update check for %%run_permissions
* Fri Dec  7 2012 saschpe@suse.de
- Add suse-manpages-for-rc-scripts.patch: Don't complain about
  missing man-pages for rc-scripts
* Thu Nov 29 2012 dimstar@opensuse.org
- Add colord uid and gid.
* Fri Nov 23 2012 saschpe@suse.de
- Add additional OpenStack users/groups
* Fri Nov 16 2012 asterios.dramis@gmail.com
- Added a patch (python3_magic_number_fix.diff) to update the magic number for
  python 3 (patch taken from upstream).
* Wed Nov 14 2012 meissner@suse.com
- whitelist org.freedesktop.AutoMount.conf (bnc#782691),
  that wants to talk to udisks
* Mon Nov  5 2012 lnussel@suse.de
- add libopenal1 to legacy exceptions again. Got lost after the
  packaging changes apparently.
* Fri Oct 12 2012 meissner@suse.com
- allow snapper dbus service after audit (bnc#759391)
* Mon Oct  8 2012 coolo@suse.com
- no longer allow semicolon in licenses
* Thu Oct  4 2012 aj@suse.de
- Remove check for /var/lock and /var/run since it's in upstream
  rpmlint already.
* Wed Sep 26 2012 aj@suse.de
- Add README.packaging.txt to explain packaging of file
  rpmlint-checks-$VERSION.tar.gz
- Package all *py files into rpmlint-checks tarball
- Add _service file to update rpmlint-checks tarball
- Add /etc/systemd.d, /etc/modules-load.d and /etc/tmpfiles.d to the
  blacklist, only users should write here.
- Blacklist the directories used by systemd.
- Remove SuSEconfig directories (update patch suse-filesystem.diff)
- Add warnings about files on tmpfs in /var/lock or /var/run.
* Wed Sep 26 2012 dmueller@suse.com
- restore LibraryPolicy from git
* Sat Sep 15 2012 coolo@suse.com
- fix one more case of scripts progs changing types
* Thu Sep 13 2012 dmueller@suse.com
- update to 1.4:
  * rpmdiff: Teach rpmdiff about pretrans and posttrans
  * SpecCheck.py: merge patch from #97, using BuildArch with
  something else than Noarch is likely a error and causing issues.
  * FilesCheck.py: Add Python 3.3 magic number
  * FilesCheck.py, InitScriptCheck.py, MenuCheck.py, Pkg.py,
    PostCheck.py: Prepare for rpm-python possibly returning script
  progs as arrays.
* Fri Aug  3 2012 thardeck@suse.com
- added icinga users and groups
* Thu Jul  5 2012 dmueller@suse.com
- remove python naming check (bnc#768247)
* Tue Jun 26 2012 lnussel@suse.de
- add libopenal1 to legacy exceptions. It's a special case since the ABI for
  openal is defined in a standard and there can be multiple
  imlementations of the standard. Therefore it's necessary to have
  some kind of prefix or suffix for packages that contain libopenal1
* Thu Jun 21 2012 lnussel@suse.de
- add bluez dbus autolaunch stub (bnc#768062)
* Mon Jun 18 2012 saschpe@suse.de
- Add several OpenStack users/groups
* Mon Jun 18 2012 aj@suse.de
- Cleanup list of SuSEconfig scripts - remove non-existant entries.
* Tue Jun  5 2012 lnussel@suse.de
- remove tdb tools binaries, not needed for PIE (bnc#765476)
* Fri Jun  1 2012 lnussel@suse.de
- add cdemu-deamon to dbus white list (bnc#764063)
* Wed May 23 2012 lnussel@suse.de
- add check for pam modules (fate#313077)
* Tue May 15 2012 lnussel@suse.de
- add texlive.texlive to whitelist (bnc#762144)
* Mon May 14 2012 lnussel@suse.de
- add 'mktex' group as used by texlive
* Wed Mar 21 2012 dmueller@suse.de
- fix false positives for swp matching
* Tue Mar 20 2012 lnussel@suse.de
- better deal with spaces in logrotate config
- add colord-sane dbus service to whitelist (bnc#752518)
* Fri Mar 16 2012 dmueller@suse.de
- fix parsing of update-alternatives and clarify info message
* Tue Mar 13 2012 dmueller@suse.de
- block .swp files as well (they are usually vi(m) backup files)
* Wed Feb 29 2012 lnussel@suse.de
- add udisks2 to dbus whitelist (bnc#742751)
- add smb4k to dbus whitelist (bnc#749065)
* Wed Feb 29 2012 dmueller@suse.de
- ignore fixed dependencies on config()
* Mon Feb 20 2012 lnussel@suse.de
- add logrotate check (bnc#677335)
* Mon Feb 20 2012 lnussel@suse.de
- NetworkManager.conf was renamed to org.freedesktop.NetworkManager.conf (bnc#747780)
* Tue Jan 31 2012 lnussel@suse.de
- suse-filelist-empty is meant as warning only
* Thu Jan 26 2012 suse@ammler.ch
- add standard group and user znc (server:irc/znc)
* Wed Jan 11 2012 vcizek@suse.com
- added standard user and group "puppet"
* Wed Jan  4 2012 dmueller@suse.de
- reenable libtool wrapper check
* Wed Dec 21 2011 dmueller@suse.de
- unbreak config afer DesktopTranslationCheck was removed
* Fri Dec 16 2011 coolo@suse.com
- create the valid licenses from list tracked by SUSE legal (dumped
  into obs-service_format_spec_file, so use that one as buildrequire)
* Tue Dec 13 2011 andreas.stieger@gmx.de
- added: standard group 'tor'
- added: standard user 'tor'
* Tue Dec 13 2011 coolo@suse.com
- the untranslated-desktop-file check is obsolete, in factory
  all .desktop files are trimmed and marked - in all other projects
  (including devel projects) %%suse_update_desktop_file won't touch
  the files for translation only
* Mon Dec  5 2011 dmueller@suse.de
- fix invalid-suse-version-chec (bnc#732671)
* Tue Nov 29 2011 lnussel@suse.de
- fix devel-package-with-non-devel-group check (bnc#732897)
* Tue Nov 29 2011 lnussel@suse.de
- enable license check
* Mon Nov 28 2011 lnussel@suse.de
- add NetworkManager-openconnect to dbus whitelist (bnc#732915)
- add global filter for SuSEfirewall2's sysconfig file as setBadness in the
  package is not allowed
* Wed Nov 23 2011 projects@localside.net
- added: standard group 'citadel'
- added: standard user 'citadel'
- changed: addDetails('non-standard-uid', ... branch paket ...',
  'non-standard-uid', ... branch paket ...')
* Sun Aug 28 2011 opensuse@cboltz.de
- add vacation/vacation to valid group/user list
  (needed for PostfixAdmin's vacation.pl script)
* Wed Aug 24 2011 dmueller@suse.de
- avoid warning with shlib policy on libtool
* Sat Aug 20 2011 dmueller@suse.de
- check for versioned dependency on python(abi) (bnc#659068)
* Fri Aug 19 2011 dmueller@suse.de
- fix stripping of unknown polkit suffixes (bnc#711485)
* Fri Aug 12 2011 dmueller@suse.de
- update to 1.3:
  * Add --rawout option
  * Warn about non-ghost files in /var/run and /var/lock
  * Fix setting message type for reasons with badness threshold defined
  * Use "declare -F" instead of "type" to check if a bash function exists.
* Fri Aug 12 2011 dmueller@suse.de
- add jenkins/jenkins to valid group/user list
* Sat Aug  6 2011 jengelh@medozas.de
- Spelling fixes
* Fri Aug  5 2011 lnussel@suse.de
- add org.kde.kalarmrtcwake to dbus whitelist (bnc#707723)
* Fri Aug  5 2011 lnussel@suse.de
- only consider executable ELF files for
  non-position-independent-executable check
- add more users and groups from Factory
* Mon Aug  1 2011 lnussel@suse.de
- add lightdm user and group (bnc#708205)
* Fri Jul 29 2011 lnussel@suse.de
- add org.freedesktop.DisplayManager.conf (bnc#708205)
* Sat Jul 23 2011 toddrme2178@gmail.com
- remove obsolete knotification-requires check
- bump obsolete openSUSE version to 11.2
* Thu Jul 14 2011 lnussel@suse.de
- add more systemd dbus services to whitelist (bnc#705677)
* Wed Jul 13 2011 lnussel@suse.de
- CheckSUIDPermissions: use non-position-independent-executable as
  accepted upstream
* Thu Jun 23 2011 dmueller@suse.de
- remove some false positives of the no-dependency-on checker
* Wed Jun 15 2011 lnussel@suse.de
- fix library policy check complaining about non-ELF files (bnc#700067)
* Tue Jun  7 2011 lnussel@suse.de
- add colord to dbus whitelist (bnc#698250)
* Tue Jun  7 2011 lnussel@suse.de
- CheckPolkitPrivs.py: use different tag for non-fatal issues
- CheckBuildDate.py: print either file-contains-current-date or
  file-contains-current-date but not both
* Tue May 31 2011 lnussel@suse.de
- add check for /var/lock/subsys usage
* Tue May 24 2011 lnussel@suse.de
- disable source-or-patch-not-compressed. Not useful anymore.
* Fri May 20 2011 lnussel@suse.de
- add synche-connector (bnc#683956) to dbus whitelist
- update system-config-printer (bnc#694640) in dbus whiteliste
* Fri May 20 2011 dmueller@suse.de
- update legacy filter in shlib policy checker
* Thu May 19 2011 lnussel@suse.de
- new version 1.2
  * Check outdated or misspelled FSF addresses in text files.
* Tue May 17 2011 lnussel@suse.de
- update rpmlint-pie.diff and suse-file-var-run.diff with upstream
  accepted variant
* Wed May 11 2011 lnussel@suse.de
- don't filter non-standard-gid anymore
- add dir-or-file-in-var-lock check
- remove 'nobody' from standard users
* Tue May 10 2011 lnussel@suse.de
- add not-a-position-independent-executable check
* Thu May  5 2011 lnussel@suse.de
- add radvd user to known list
- add org.freedesktop.hostname1 to dbus whitelist (641924)
* Mon May  2 2011 lnussel@suse.de
- add account services (bnc#676638)
* Mon May  2 2011 lnussel@suse.de
- another try to fix InitScriptCheck.py (bnc#690961)
* Wed Apr 27 2011 dmueller@suse.de
- implement setFilterException()
- rediff noarch-lib64.diff and enable it again (bnc#663885)
* Tue Apr 26 2011 dmueller@suse.de
- make error description more clearn (bnc#686328)
* Sat Apr 23 2011 dmueller@suse.de
- fix abort in BinariesCheck
- fix sysv5-init-check.diff for real
* Thu Apr 21 2011 lnussel@suse.de
- fix sysv5-init-check.diff to not throw exception
* Wed Apr 20 2011 dmueller@suse.de
- fix sysv5-init-check.diff to check for preun, not postin
* Tue Apr 19 2011 lnussel@suse.de
- update CheckInitScripts.py:
  * add check for runlevel 4
  * clarify boot.* error
  * accept $null in start/stop tags
- also check for %%run_permissions if package doesn't actually need permissions
  handling
- merge suse-binarieschecks.diff and suse-hide-unstripped-outside-build.diff
  and fix the former
* Tue Apr 19 2011 lnussel@suse.de
- ignore dir-or-file-in-usr-local as it's handled by CheckFilelist.py
- non-standard-dir-in-usr dito
* Tue Apr 19 2011 lnussel@suse.de
- add urfkill (bnc#688328))
* Fri Apr 15 2011 dmueller@suse.de
- update to 1.1:
  - remove upstreamed patches
  * FilesCheck.py: Don't crash if a file cannot be opened
  * FilesCheck.py: Update expected Python 3.2 bytecode magic value
  * TagsCheck.py: Improve no-description-tag info message
  * TagsCheck.py: Improve changelog related info messages.
  * Pkg.py: Treat 'Unspecified' as a valid Group
  * TagsCheck.py: Add future and overflow checks for changelog
  * FilesCheck.py: Don't emit spurious executable perm warnings for
    docs with shebangs
  * FilesCheck.py: Don't read "head" of files for in each test
  * SpecCheck.py: Check source and patch file sizes and MD5 hashes
  * Pkg.py: Fix traceback when stringifying epoch-only versions
  * TagsCheck.py: Fix TypeError when outputting
  * Pkg.py: Make file capabilities available in PkgFile
- add check for missing rcXXX symlinks (FATE#310641)
* Mon Mar 21 2011 lnussel@suse.de
- add NetworkManager to dbus whitelist (bnc#681128)
- add wpa_supplicant to dbus whitelist (bnc#681116)
* Wed Mar 16 2011 dmueller@suse.de
- fix typo (bnc#675329)
* Thu Mar 10 2011 lnussel@suse.de
- add better help message for non-standard-uid
* Wed Feb 16 2011 lnussel@suse.de
- add kde backlight helper to whitelist (bnc#672145)
* Wed Feb  9 2011 lnussel@suse.de
- add webyast to dbus whitelist (bnc#660981)
* Thu Jan 13 2011 lnussel@suse.de
- add hal dbus system activation file too
* Wed Jan 12 2011 lnussel@suse.de
- add mumble-server to dbus white list (bnc#660784)
* Mon Jan 10 2011 lnussel@suse.de
- add NetworkManager-strongswan to dbus white list (bnc#656222)
* Sun Dec 19 2010 jw@novell.com
- Fix message for no-changelogname-tag:
  This is also caused by missing changes file.
  Original message posed a contradiction, in case the
  %%changelog section header was there.
* Wed Nov 24 2010 dmueller@suse.de
- remove filter for no-url-tag (bnc#642588)
- clarify wording for run_ldconfig check (bnc#637187)
- skip desktop files in /etc (bnc#604283)
* Fri Nov 19 2010 dmueller@suse.de
- fix exception on postgresql build
* Thu Nov 18 2010 lnussel@suse.de
- also check ghost files for permission violations
* Wed Nov 17 2010 lnussel@suse.de
- add check for %%set_permissions
* Tue Nov 16 2010 lnussel@suse.de
- modify match in CheckSUIDPermissions to work with new macros
- allow info messages even if badness scoring is used
* Mon Nov 15 2010 dmueller@suse.de
- change Documentation/SuSE to /SUSE (bnc#618716)
- whitelist "openSUSE" at start of Summary (bnc#618716)
* Sun Nov 14 2010 dmueller@suse.de
- remove invocations of expandMacro()
* Thu Nov 11 2010 dmueller@suse.de
- fix another exception in branding policy check (bnc#652628)
* Thu Nov  4 2010 lnussel@suse.de
- enable suse-hide-unstripped-outside-build.diff again
* Thu Nov  4 2010 lnussel@suse.de
- check for file system capabilities
- check for %%verifyscript and %%run_permissions
* Wed Nov  3 2010 dmueller@suse.de
- update to 1.0:
  * add support for PEP 3147 when handling python bytecode
  * various doc improvements
* Fri Oct 29 2010 lnussel@suse.de
- remove debug logging
- fix BrandingPolicy.py
* Wed Oct 27 2010 dmueller@suse.de
- fix supplements parsing (bnc#648404)
* Thu Oct 21 2010 dmueller@suse.de
- add build time check (bnc#635351)
* Tue Oct 19 2010 lnussel@suse.de
- init script check logic
* Tue Oct 19 2010 lnussel@suse.de
- add all currently known dbus services as legacy exception
* Tue Oct 19 2010 lnussel@suse.de
- add configurable whitelist to CheckDBUSServices.py
* Fri Oct 15 2010 dmueller@suse.de
- fix regression in suse-binariescheck.diff
* Tue Oct 12 2010 lnussel@suse.de
- add check for gnome and desktop related macros
* Sun Oct  3 2010 andrea@opensuse.org
- Added lxdm as a valid group and user
* Mon Sep 27 2010 dmueller@suse.de
- update to 0.99:
  * Add Python 2.7 magic number ( https://bugzilla.redhat.com/623607, Nils Philippsen)
* Mon Sep 27 2010 dmueller@suse.de
- update to 0.98:
  * Pkg.py, test/test.Pkg.py: Fix self-obsoletion bug with Provides
    containing Epoch.
  * Pkg.py: Don't stringify None Epoch to 'None' string in
    compareEVR().
  * Pkg.py: Sync rangeCompare() with yum 3.2.27.
  * TagsCheck.py: Reduce some spell check noise.
  * rpmlint: Fix handling of arguments containing spaces.
  * DocFilesCheck.py: Bypass doc file check earlier if package has no
    doc files.
* Thu Aug 19 2010 dimstar@opensuse.org
- Add suse-g-ir-chech.diff: *.gir belong in -devel packages.
* Sun Aug  8 2010 vuntz@opensuse.org
- Update suse-version.diff: last non-obsolete version of openSUSE
  is 11.1, and latest valid version of openSUSE is 11.4.
* Thu Jul 29 2010 dmueller@suse.de
- fix printWarning error in CheckBashisms
* Thu Jul 29 2010 puzel@novell.com
- add confusing-invalid-spec-name.patch
* Tue Jul 20 2010 guido+opensuse.org@berhoerster.name
- add BashismsCheck
* Mon Jul 12 2010 dmueller@suse.de
- add Development/Debug group (bnc#612044)
* Wed Jun 30 2010 lnussel@suse.de
- additionally look at the BUILD_DEBUG variable to determine whether
  a warning should be printed. Needs an updated 'build' script.
* Tue Jun 29 2010 lnussel@suse.de
- don't print unstripped binary warning when used with build script
  (bnc#618004)
* Mon Jun  7 2010 andrea@opensuse.org
- added "System/GUI/LXDE" as a valid rpmgroup
* Wed May  5 2010 lnussel@suse.de
- don't allow perl vendorarch in noarch packages
* Thu Apr 29 2010 dmueller@suse.de
- check for gethostbyname calls (bnc#506945)
* Thu Apr 29 2010 dmueller@suse.de
- fix branding check (bnc#579556)
* Wed Apr 28 2010 dmueller@suse.de
- fix exception in interpreter check
- restrict shlib-fixed-dependency to shlib-policy packages
- allow files in /tmp to be listed as %%ghost
* Tue Apr 27 2010 dmueller@suse.de
- tighten pkg-config check
* Mon Apr 26 2010 dmueller@suse.de
- check for missing xinetd.d (bnc#436326)
- check for files in /var/run (fate#303793)
* Thu Apr 22 2010 dmueller@suse.de
- check for live update problems (bnc#477649)
- rediff and enable the shared lib dependency check fix
* Wed Apr 21 2010 aj@suse.de
- Add some missing rpm groups and sort list.
* Mon Apr 19 2010 dmueller@suse.de
- tighten the interpreter check (bnc#574650)
* Fri Apr 16 2010 dmueller@suse.de
- suppress warnings about cron.d symlinks (bnc#591431)
* Tue Apr  6 2010 dmueller@suse.de
- workaround unicode error exceptions on non-utf8 filenames
* Fri Apr  2 2010 dmueller@suse.de
- rediff some suse specific patches
* Thu Mar 25 2010 dmueller@suse.de
- fix buildroot detection (bnc#584952)
* Fri Mar 19 2010 dmueller@suse.de
- update to 0.95:
  * Skip ghost files in files checks,  https://bugzilla.redhat.com/570086
  * Work around Python's ASCII non-TTY stdout and our non-ASCII output.
  * Omit spell check warnings for capitalized words that do not start a sentence.
  * Wrap bunch of long lines, tune comments and info messages.
  * Require rpm-python >= 4.4.2.2 for expandMacro() in r1729.
  * do not execute check if the network test are marked as disabled, and simplify the logic
  * do not expand the format of the filename format, (patch from Per Oyvind Karlsten )
* Sat Feb 27 2010 dmueller@suse.de
- update to 0.94:
  - rpm 4.8.0 support
  - better python bytecode checks
  - improved LSB/taglist
  - various fixes/patches upstreamed
* Thu Feb 25 2010 lnussel@suse.de
- update and enable CheckPolkitPrivs
* Fri Feb 19 2010 puzel@novell.com
- update suse version check (add 11.2, drop 10.3)
* Mon Feb  1 2010 lnussel@suse.de
- fix usr-arch.diff
- require python-magic as it's needed by some checks
* Wed Jan 13 2010 lnussel@suse.de
- suppress depmod warnings (bnc#456048)
* Sun Jan 10 2010 detlef@links2linux.de
- add some missing groups
* Sat Jan  9 2010 lnussel@suse.de
- disable badness for group check until we know the impact
* Fri Jan  8 2010 detlef@links2linux.de
- add a config file for standard RPM groups
* Thu Jan  7 2010 mvyskocil@suse.cz
- fixed bnc#566018 - no-ghost-alternative-file check makes no sense
  - fixed CheckAlternativesGhostFiles test, renamed the warnings to
    generic-name-not-in-filelist, generic-name-not-marked-as-ghost
* Sat Jan  2 2010 jengelh@medozas.de
- enable parallel build
* Sat Nov 14 2009 dmueller@suse.de
- update to 0.92:
  * various fixes and python 3 compatibility added
  * new checks for python compiled files
* Wed Oct  7 2009 dmueller@suse.de
- tighten the regex for libraries (bnc#544906)
* Wed Sep 30 2009 dmueller@suse.de
- fix exceptions in BinaryInfo
* Wed Sep  9 2009 dmueller@suse.de
- update to 0.90:
  * Makefile: 0.90.
  * rpmdiff: Add missing magic coding comment
  (https://bugzilla.redhat.com/508683, Michal Nowak).
  * TagsCheck.py: Fix incorrect info in self-obsoletion message.
  * FilesCheck.py: Output interpreter in non-executable-script
  warning, remove quotes from wrong-script-interpreter one.
  * Pkg.py: Remove stale comments.
  * TagsCheck.py: Code cleanup, NFC.
  * TagsCheck.py: improve percent-in-* message details.
  * TagsCheck.py: Remove obsolete-on-name check (superseded by
  self-obsoletion).
  * TagsCheck.py: Add check for self-obsoletion cases,
  https://bugzilla.redhat.com/461610
  * Pkg.py: Borrow various utilities from yum's rpmUtils.miscutils.
  * Makefile, rpmUtils: Revert previous commit.
  * Makefile, rpmUtils, rpmUtils/miscutils.py,
  rpmUtils/transaction.py: Borrow
  rpmUtils/{miscutils,transaction}.py from yum.
  * rpmdiff: Improve dependency formatting.
  * rpmdiff: Take Epoch into account in self-provides filtering.
  * Pkg.py: Improve legacy prereq tracking with new rpm versions.
  * BinariesCheck.py: Don't output missing-PT_GNU_STACK-section
  messages if readelf failed.
  * FilesCheck.py: Add check for debuginfo packages without sources.
  * FilesCheck.py: Allow more common files to be non-readable
  (https://bugzilla.redhat.com/226412).
  * FilesCheck.py: Revert relative symlink target normalization back
  to more aggressive.
  * BinariesCheck.py, Config.py, ConfigCheck.py, FHSCheck.py,
  FilesCheck.py, I18NCheck.py, MenuCheck.py, Pkg.py, PostCheck.py,
  TagsCheck.py, rpmdiff: Code cleanups.
  * FilesCheck.py: Do not check existence of relative link targets on
  the filesystem for consistency with absolute link target checks,
  improve dangling-*symlink info messages.
  * FilesCheck.py, Pkg.py: Be a bit stricter when normalizing link
  targets, do it earlier.
  * FilesCheck.py, Pkg.py: Improve link target normalization in
  symlink checks.
- filter cross-directory-hard-link as it is duplicate to a suse
  check
* Mon Sep  7 2009 dmueller@suse.de
- filter buildroot related checks (bnc#536594)
* Fri Aug 28 2009 mvyskocil@suse.cz
- Added CheckAlternativesGhostFiles.py - see bnc#534451 comment#17
* Wed Aug 26 2009 lnussel@suse.de
- disable bogus patch to InitScriptCheck.py. Causes failures and
  needs to be reworked
- fix and add weak dependencies patch again to make some suse checks
  work
* Wed Aug 26 2009 lnussel@suse.de
- fix CheckPkgConfig.py to work with rpmlint 0.87
* Wed Aug 26 2009 lnussel@suse.de
- refresh some patches to remove fuzz
- BuildIgnore rpmlint-mini as it is currently broken
* Mon Aug 24 2009 lnussel@suse.de
- don't import pprint in CheckSUIDPermissions.py
- remove /selinux again. No package except 'filesystem' is supposed
  to include that.
- add filter for FHS violation of skelcd type packages
- fix some more suse patches
* Mon Aug 10 2009 thomas@novell.com
- added /selinux to allowed prefixes in CheckFilelist.py
* Wed Jul 29 2009 lnussel@suse.de
- add cups to dbus whitelist (bnc#515977)
* Mon Jul 20 2009 lnussel@suse.de
- fix suse checks for 0.87
* Thu Jul 16 2009 lnussel@suse.de
- fix syntax error in suse-hide-unstripped-outside-build.diff
* Sun Jun 21 2009 dmueller@suse.de
- update to 0.87:
  * remove old rpm support
  * improved performance and compat with python 2.6
  * many pylint/pychecker code fixes
* Sat Apr  4 2009 dmueller@suse.de
- fix library policy checker being inactive due to API change
* Fri Feb 27 2009 dmueller@suse.de
- update to 0.85:
  * various new checks and fixes to existing checks
  * remove upstreamed patches
* Thu Feb 26 2009 lnussel@suse.de
- use separate error for sysconfig stuff (bnc#470965)
- move RCS detection to FilesCheck.py
- remove explicit requires on python, already handled by %%py_requires
* Mon Feb  9 2009 lnussel@suse.de
- remove check for /usr/share/info/dir from CheckFilelist.py,
  already in upstream FilesCheck.py
- fix exception for texinfo
* Mon Feb  2 2009 dmueller@suse.de
- improve information hint for perl blacklisted paths
- fix language list for sr (bnc#471254)
* Fri Jan 30 2009 lnussel@suse.de
- add exception for nfs-utils, texinfo and perl
- allow backup files if they are ghost files
* Fri Jan 23 2009 lnussel@suse.de
- add check for DBus Policy problems
* Tue Jan 13 2009 lnussel@suse.de
- CheckFilelist: optimize FHS check to only complain about wrong
  directories rather than hundreds of individual files
* Mon Jan 12 2009 lnussel@suse.de
- CheckFilelist: add exceptions for kde and pam
- CheckPolkitPrivs: use info instead of warning to avoid badness assignment
* Thu Jan  8 2009 lnussel@suse.de
- prefix dbus check with suse-
- add filelist check
* Wed Dec 17 2008 dmueller@suse.de
- add whitelist entry for libieee1284
* Thu Dec 11 2008 lnussel@suse.de
- add a check for PolicyKit privileges (disabled atm)
- add check for DBUS services
* Wed Dec  3 2008 dmueller@suse.de
- update suse version check (add 11.1, drop 10.2)
- check library packages more strict (bnc#456053)
- ignore shared objects in a versioned non-std subdir (bnc#435588)
* Thu Nov 20 2008 dmueller@suse.de
- only test for regular files in ChkPkgConfig check
* Fri Nov  7 2008 dmueller@suse.de
- add check for otherproviders() in branding packages
- correct kde4 related dependency checkers to not give false advises
- check for wrong-arch references in pkgconfig files (graphviz)
- lower false positives of untranslated-desktop files check
- support for checking .comment.SUSE.OPTs. real check has been
  left out for now
* Tue Nov  4 2008 lnussel@suse.de
- generate a different error for directories with setuid/setgid bit
* Tue Oct 28 2008 lnussel@suse.de
- add check for /etc/permissions violations
* Fri Oct  3 2008 dmueller@suse.de
- update to 0.84:
  * remove upstreamed patches
  * no significant changes
* Wed Sep  3 2008 dmueller@suse.de
- add description for useless-explicit-requires (bnc#405887)
* Wed Aug 20 2008 dmueller@suse.de
- rediff patch
* Mon Aug 18 2008 schwab@suse.de
- Fix name of completions file.
* Tue Aug 12 2008 dmueller@suse.de
- be more verbose in the lsb init script checks
* Mon Aug  4 2008 dmueller@suse.de
- change mandatory-lsb-keyword check to be in line with insserv
* Tue Jul 29 2008 dmueller@suse.de
- remove python-base in the warning as it is confusing.
  the warning itself is still valid though
- fix config typo
* Mon Jul 21 2008 dmueller@suse.de
- enable non-conffile-in-etc warning (bnc#409643)
- fix shlib policy dependency warnings (bnc#405280)
* Tue Jul  1 2008 dmueller@suse.de
- update cron dependency checker (bnc#400921)
* Sun Jun 29 2008 schwab@suse.de
- No PT_GNU_STACK on ia64 and ppc64.
* Fri Jun 27 2008 dmueller@suse.de
- also read /etc/rpmlint/factory.config
* Fri Jun 27 2008 dmueller@suse.de
- fix typo in suse-version check
* Sun Jun 22 2008 dmueller@suse.de
- update to 0.83:
  * removed upstreamed patches
  * a couple of new checks, bugfixes
* Wed Jun 18 2008 dmueller@suse.de
- fix exception in tags check (bnc#399655)
- add a warning for self-conflicts
* Thu Jun  5 2008 dmueller@suse.de
- fix naming policy check for lib64 based archs (bnc#392524)
* Tue May 13 2008 dmueller@suse.de
- fix typo in kde4 deps check
* Mon May  5 2008 dmueller@suse.de
- fix typo in branding policy check
* Fri May  2 2008 dmueller@suse.de
- readd cron check
- fix kmp check after the policy change
* Wed Apr 30 2008 dmueller@suse.de
- add checker for correct deps of kde4 packages
- add check for mono requirements (BNC#381979)
- improve branding policy checks
- add support for weak/reverse dependencies
- add checks for percent's in weak/reverse dependencies
- add checks for incorrect kmp dependencies (bnc384084#)
* Tue Apr 22 2008 dmueller@suse.de
- fix exception on testing for unversioned branding provides
* Mon Apr 21 2008 dmueller@suse.de
- suppress script warnings about /var/adm/fillup-templates (bnc#379601)
- add start of a branding policy checker
* Fri Apr 18 2008 jblunck@suse.de
- Fix some regex in BinariesCheck
* Thu Apr 17 2008 jblunck@suse.de
- Add symtab and debuginfo tests for static libs
* Thu Mar 13 2008 dmueller@suse.de
- autogenerate users/groups from autobuild (bnc#374601)
- suppress non-devel buildrequire dependency for tcl
- fix licenses symlink handling (bnc#370364)
- allow /usr/share/locale/be@latin (bnc#370418)
* Tue Mar 11 2008 dmueller@suse.de
- fix some false positives
* Mon Mar 10 2008 dmueller@suse.de
- add check for a really short description
* Thu Mar  6 2008 dmueller@suse.de
- be less restrictive in pkgconfig checks
* Mon Mar  3 2008 dmueller@suse.de
- suppress tag-not-utf8 warnings for now
* Thu Feb 28 2008 dmueller@suse.de
- add check for %%run_ldconfig
* Thu Feb 28 2008 dmueller@suse.de
- improve check output
* Tue Feb 26 2008 dmueller@suse.de
- improved tags check
- cleanups
* Mon Feb 25 2008 dmueller@suse.de
- reduce package-size-check false positives
- add another postscript check
* Tue Feb 19 2008 dmueller@suse.de
- fix typo in sorting routine
* Fri Feb 15 2008 dmueller@suse.de
- updated spec file name-guessing to catch more cases
- updated dot-in-identifier check
- suppression updates
* Tue Feb 12 2008 dmueller@suse.de
- update to 0.82:
  * some patches were upstreamed
  * small bugfixes
- rework fix for bnc#354177 to consider python bytecode
  arch-independent again, but catch it in arch-dependent paths
* Sat Feb  9 2008 dmueller@suse.de
- fix some minor buglets
* Tue Feb  5 2008 dmueller@suse.de
- consider python bytecode to not be arch independent (bnc#354177)
- improve postcheck to ignore unexpanded macros in comments (bnc#355306)
- check binary rpath for perl version dependency (bnc#355053)
- add check for unversioned self-provides
- update suse checks from SVN
- check for dot's in dependencies - forbidden by autobuild policy
* Wed Jan 23 2008 dmueller@suse.de
- improve documentation
* Mon Jan 14 2008 dmueller@suse.de
- check for libtool wrapper scripts being packaged (#353240)
* Wed Dec 12 2007 dmueller@suse.de
- reapply patch-detection fix
* Mon Dec  3 2007 dmueller@suse.de
- add suppression for libzypp
- fix wrong indentation in verify-buildrequires
* Fri Nov 30 2007 dmueller@suse.de
- bugfixes in check-mkdir-buildroot
- bugfix in percent-post check
- check for buildroot in %%post scriptlets
- remove abused legacy shared lib policy exceptions
- suppression update
* Mon Nov 26 2007 dmueller@suse.de
- fix suppression for internal packages
* Fri Nov 23 2007 dmueller@suse.de
- add suppression for non-remote_fs on boot.* (#340588)
* Wed Nov 21 2007 dmueller@suse.de
- add warning for non-utf8 filenames (#343216)
* Tue Nov  6 2007 dmueller@suse.de
- more prereq checks
* Mon Nov  5 2007 dmueller@suse.de
- suppression update
- add more prereq checks
* Fri Nov  2 2007 dmueller@suse.de
- fix prereq parsing code (#336712)
- update the obsolete-suse-version check to include 10.0 and 11.0
- fix prereq checks to check for coreutils
* Wed Oct 31 2007 dmueller@suse.de
- reporting format change-back got rejected by upstream,
  so adopt other changes to deal with it
* Tue Oct 30 2007 dmueller@suse.de
- change back reporting format to list the severity
  first
- add more legacy suppressions found by library policy
  fix
* Mon Oct 29 2007 dmueller@suse.de
- also check for Library Policy errors in /opt/kde3/lib
* Mon Oct 29 2007 dmueller@suse.de
- update to 0.81:
  * various new checks, some bugfixes
  * many patches upstreamed
  * rediffed all other patches
- NOTE: output format has changed from
  W: package check-id ..
  to
  package.<arch>: W: check-id ..
* Sun Oct  7 2007 dmueller@suse.de
- another round of updates
* Fri Oct  5 2007 dmueller@suse.de
- library policy legacy suppression update
* Mon Oct  1 2007 mmarek@suse.cz
- added 'mysql' to the list of standard users and groups
- removed 'jonas' (dropped package) from that list
* Tue Sep 25 2007 dmueller@suse.de
- update library policy checker for libgcc and libcaca
- check for /usr/share/gnome/help in documentation checks (#310134)
* Thu Sep 20 2007 dmueller@suse.de
- add check for non-whitelisted filedependencies (#326803)
* Mon Sep  3 2007 dmueller@suse.de
- fix hardlink check for /bin
* Sat Sep  1 2007 schwab@suse.de
- Fix last change.
* Fri Aug 31 2007 dmueller@suse.de
- fix off-by-one in hardlink check
* Fri Aug 31 2007 dmueller@suse.de
- fix exception in DuplicatesCheck
* Thu Aug 30 2007 dmueller@suse.de
- fix buildroot false positive
- check for hardlinks across partitions (#304167)
* Wed Aug 29 2007 dmueller@suse.de
- improve mkdir-installroot check
- fix rpmlint package regarding check above ;)
* Wed Aug 29 2007 mmarek@suse.cz
- improved the non-devel-buildrequires check
- added some default filters for non-devel-buildrequires and
  unneccessary-buildrequires
* Wed Aug 22 2007 dmueller@suse.de
- check for wrong cleaning of buildroot in %%install (#300232)
- check for obscure and unneccessary buildrequires
- add an icon size check (#163547)
* Tue Aug 21 2007 dmueller@suse.de
- refine the $remote_fs dependency check
* Sun Aug 12 2007 dmueller@suse.de
- suppression update
* Sat Aug 11 2007 dmueller@suse.de
- improved macro checks
- documentation update
* Fri Aug 10 2007 dmueller@suse.de
- detect makefile junk (#217472)
- suppression update
- fix a couple of false positives
* Tue Jul 31 2007 dmueller@suse.de
- fix package-with-huge-docs check to not complain about
  documentation-only packages
- remove verbosity from the shared library packaging policy check
* Tue Jul 24 2007 dmueller@suse.de
- fix man page check false positives
- make package-with-huge-docs check less verbose
* Tue Jul 17 2007 dmueller@suse.de
- accept lua as a builtin shell
- fix false positives on filesystem package
- add check for init scrips missing $remote_fs
* Wed Jul 11 2007 dmueller@suse.de
- adjust library policy suppressions for opal and pwlib (#290347)
- fix readme check (#291150)
* Mon Jul  9 2007 dmueller@suse.de
- its also a devel package if it provides a -devel subpackage (#289735)
* Wed Jul  4 2007 dmueller@suse.de
- suppress %%config check for now (#286231)
* Tue Jun 26 2007 dmueller@suse.de
- fix typo in devel-rpmgroup check
* Mon Jun 25 2007 dmueller@suse.de
- another update list of legacy packages
* Sat Jun 23 2007 dmueller@suse.de
- update list of legacy packages
* Fri Jun 22 2007 dmueller@suse.de
- suppressions for mono related packages (#282121)
* Fri Jun 22 2007 dmueller@suse.de
- fix the bzip2/gzip confusion again
* Fri Jun 22 2007 dmueller@suse.de
- update list of legacy packages
* Thu Jun 21 2007 dmueller@suse.de
- add list of legacy package names with non-policy conform
  package name
- check updates from SVN
* Thu Jun 21 2007 dmueller@suse.de
- suppression update
- suppress devel-file-in-non-devel package if its just a compat
  symlink to another .so
- avoid unstripped binaries warnings in BETA
- fix filesystem lint false positives
* Wed Jun 13 2007 dmueller@suse.de
- suppression update
- add descriptions to sysv5 init checks
- use readelf for binary info to improve performace
- check if source patch/tarballs is not bzip2'ed and bigger
  than 100k (suse packaging conventions requirement)
- check if package contains excessive sized documentation
* Mon Jun 11 2007 dmueller@suse.de
- hide errors related to .packlist files from perl
  still need to figure out though why they're there
* Mon Jun 11 2007 dmueller@suse.de
- fix build
* Sat Jun  9 2007 dmueller@suse.de
- make the buildroot check work
- make the buildroot check factor 10-15 faster
- fix the pkgconfig check
* Fri Jun  8 2007 dmueller@suse.de
- fix warning-hide hack (#279865)
- description update
* Fri Jun  8 2007 dmueller@suse.de
- hide unstripped-binary-or-object warning outside build (#279865)
- fix typo in library policy check
- adopt library checks for suse library packaging policy
- add check for unnecessarily packaged files
- description update
- suppression update
* Thu May 31 2007 dmueller@suse.de
- suppression update
- fix various checks
- add checks for init scripts
* Wed May 30 2007 dmueller@suse.de
- update LibraryPolicy Checker
* Tue May 29 2007 dmueller@suse.de
- suppression update
- fix XDG menu checker to also include non-/usr paths
- fix ghost-file-creation check to skip missingok files (#278761)
* Mon May 28 2007 dmueller@suse.de
- suppression-update
- Library Policy Checker crash fixes (#278592)
* Sat May 26 2007 dmueller@suse.de
- add description for missing lsb tags check
- fix obsolete-not-provided for yast2-provides
- fix devel-file check matching module names (e.g. apache2)
* Fri May 25 2007 dmueller@suse.de
- avoid spurious executable warnings for docdatadir/examples
- add LibraryPolicy checker from Richard (warning only)
- suppression update
* Thu May 24 2007 dmueller@suse.de
- fix suppression for qa_ packages
- fix exceptions caused by DesktopTranslation check
- fix crash caused by trailing colons in requires
* Thu May 24 2007 dmueller@suse.de
- fix file paths in Duplicate and DesktopTranslation checks
* Thu May 24 2007 dmueller@suse.de
- update sourced-dirs list
- add some more standard users
- add suppression for devel-file-in-non-devel package in java
- filter some more noise
* Wed May 23 2007 dmueller@suse.de
- add descriptions for obsolete suse version check
- suppress some more noise
- don't run duplicates check for source rpms
* Wed May 23 2007 dmueller@suse.de
- suppress errors for cross-avr-*
- suppress devel-packaging-naming errors for gcc41, gcc42
* Wed May 23 2007 dmueller@suse.de
- group output by check and put errors last (#276943)
- suppress some more noise (#277308)
- suppress %%ifarch-applied-patch (#277316)
- more suppressions for misnamed devel packages (#277317)
* Wed May 23 2007 dmueller@suse.de
- Suppress errors about platform dependent code in /usr/share
  if its inside a platform-dependant subdirectory
- Suppress devel-file-in-non-devel-package for systemtap (#277338)
- Make sure that the package fails if there is any syntax
  error anywhere
* Tue May 22 2007 dmueller@suse.de
- typo fix
* Tue May 22 2007 dmueller@suse.de
- update config
* Sat May 19 2007 coolo@suse.de
- add three more checks
* Thu May 17 2007 dmueller@suse.de
- update Duplicates Check to not crash on ghost files
* Tue May 15 2007 dmueller@suse.de
- suppress bzip2 related warnings
- no documentation for lib packages
* Tue May 15 2007 coolo@suse.de
- add a check how much space is wasted by duplicated files
* Mon May 14 2007 dmueller@suse.de
- remove rpm-devel requirement
- add check for filerequires on /usr/bin/env
- fix syntax errors in previous change
* Mon May 14 2007 coolo@suse.de
- add a check for /opt/kde3 not in %%doc or in %%lang
- fix files not in %%lang check
* Wed May  9 2007 dmueller@suse.de
- remove tabs from sources
* Mon May  7 2007 dmueller@suse.de
- fix desktop file check (#252482)
* Sat May  5 2007 dmueller@suse.de
- allow extensions to LSB starting with "X-" (#271495)
* Fri May  4 2007 dmueller@suse.de
- remove check for usedforbuild tag. magic happens and
  it is created automatically
* Wed Apr 18 2007 dmueller@suse.de
- add spec checks for obsolete suse hacks
* Wed Apr 18 2007 dmueller@suse.de
- update to 0.80:
  * many more checks
- suppression updates
* Thu Apr  5 2007 dmueller@suse.de
- suppressions for OpenOffice and linux-kernel-headers
* Thu Apr  5 2007 dmueller@suse.de
- update suppressions
* Wed Nov  8 2006 dmueller@suse.de
- fix compatibility with rpm-python of sles9 (#216081)
* Mon Sep 11 2006 dmueller@suse.de
- update to 0.77:
  * updated checks regarding FHS compliance
  * some python-lint fixlets
* Wed Apr 12 2006 dmueller@suse.de
- update to 0.76
* Fri Mar 24 2006 dmueller@suse.de
- update to 0.75
* Tue Mar 21 2006 dmueller@suse.de
- suppress some glibc related errors (#157906)
* Wed Feb 22 2006 dmueller@suse.de
- add km to the list of valid locales
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 dmueller@suse.de
- add check for untranslated desktop files
* Tue Dec 20 2005 dmueller@suse.de
- fix i18n subdir check
* Thu Dec 15 2005 dmueller@suse.de
- filter init-script-name-with-dot /etc/init.d/boot.* and
  script-without-shellbang /etc/profile.d/*
* Thu Nov 24 2005 dmueller@suse.de
- update to 0.71
- strip "requires-on-release" for now, too much noise
* Fri Jul 22 2005 dmueller@suse.de
- ignore dir-or-file-in-opt
* Mon Jun 20 2005 coolo@suse.de
- update to 0.70
* Thu Jun 16 2005 dmueller@suse.de
- upgrade to rpmlint 0.69
- split out the config file from the SUSE patch
* Thu Nov 11 2004 coolo@suse.de
- remove some MDK specific tests and add some SUSE specific tests
* Mon Feb 23 2004 hmacht@suse.de
- building as non-root
* Wed Jun 11 2003 coolo@suse.de
- initial version
